# -*- coding: utf-8 -*-
from __future__ import unicode_literals
from .. import Provider as AddressProvider


class Provider(AddressProvider):
    city_formats = ("{{city_name}}", )

    building_number_formats = ("%號", "%#號", "%##號", )
    postcode_formats = ("%####", "%##", )

    street_name_formats = ("{{street_name}}", )
    street_address_formats = ("{{street_name}}{{building_number}}", )

    address_formats = ("{{postcode}} {{city}}{{street_address}}", )
    secondary_address_formats = ('#樓', '之#')

    street_names = ("中正路", "中山路", "民生路", "中華路", "和平路",
                    "中興路", "仁愛路", "復興路", "民族路", "民權路",
                    "忠孝路", "信義路", "成功路", "新興路", "忠孝街",
                    "和平街", "信義街", "仁愛街", "文化路", "大同路",
                    "三民路", "新生路", "光復路", "自強路", "光明路",
                    "公園路", "民生街", "文化街", "中興街", "建國路",
                    "民權街", "自強街", "中山路１段", "中山路２段", "光明街",
                    "成功街", "永安街", "四維路", "新興街", "民族街",
                    "福德街", "大同街", "文昌街", "復興街", "博愛街",
                    "博愛路", "光華街", "太平路", "水源路", "新生街",
                    "四維街", "大仁街", "中央路", "大智街", "林森路",
                    "八德路", "長春路", "南街", "福德路", "光華路",
                    "八德街", "中山路３段", "東興路", "勝利街", "文昌路",
                    "三民街", "大勇街", "民有街", "自由路", "長安街",
                    "明德路", "明德街", "光復街", "德街", "忠義路",
                    "中和路", "自由街", "中正路１段", "永和街", "延平路",
                    "正義路", "五福街", "華興街", "育英路", "平和路",
                    "福安街", "中正路２段", "勝利路", "育英街", "興街",
                    "自立街", "民享街", "大智路", "民治街", "民治路",
                    "學府路", "中華街", "忠義街", "和街", "民富街",)

    cities = ("基隆市", "台北市", "新北市", "桃園縣", "新竹市",
              "新竹縣", "苗栗縣", "台中市", "彰化縣", "南投縣",
              "雲林縣", "嘉義市", "嘉義縣", "台南市", "高雄市",
              "屏東縣", "台東縣", "花蓮縣", "宜蘭縣", "澎湖縣",
              "金門縣", "連江縣")

    # from
    countries = ("阿爾巴尼亞", "剛果共和國", "阿爾及利亞", "丹麥",
                 "安哥拉", "多明尼加", "安圭拉", "多米尼克",
                 "阿根廷", "厄瓜多爾", "亞美尼亞", "埃及",
                 "阿路巴", "薩爾瓦多", "澳大利亞", "厄利垂亞",
                 "奧地利", "愛沙尼亞", "亞塞拜然", "衣索匹亞",
                 "巴哈馬", "斐濟", "巴林", "芬蘭", "孟加拉", "法屬玻里尼西亞",
                 "法國", "巴貝多", "加彭", "白俄羅斯", "喬治亞",
                 "比利時", "德國", "貝里斯", "迦納", "貝南", "直布羅陀",
                 "百慕達", "英國", "不丹", "希臘", "玻利維亞", "格瑞那達",
                 "波希尼亞及赫塞哥維那", "瓜地馬拉", "波札那", "幾內亞",
                 "巴西", "蓋亞那", "汶萊", "海地", "保加利亞", "宏都拉斯",
                 "布吉納法索", "香港", "蒲隆地", "匈牙利", "柬埔寨", "冰島",
                 "喀麥隆", "印度", "加拿大", "印尼", "維德角島", "依朗",
                 "開曼群島", "伊拉克", "中非共和國", "愛爾蘭", "查德", "以色列",
                 "智利", "義大利", "中國大陸", "牙買加", "哥倫比亞", "日本",
                 "剛果", "約旦", "科克群島", "肯亞", "哥斯大黎加", "韓國",
                 "象牙海岸", "科威特", "克羅埃西亞", "寮國", "塞浦路斯", "拉脫維亞",
                 "捷克", "賴索托", "盧森堡", "聖露西亞", "澳門", "聖文森及格瑞那丁",
                 "馬其頓", "聖多美及普林西比", "馬達加斯加", "沙烏地阿拉伯",
                 "馬拉威", "塞內加爾", "馬來西亞", "塞席爾", "馬爾地夫", "獅子山",
                 "馬利", "新加坡", "馬爾他", "斯洛伐克", "模里西斯", "斯洛維尼亞",
                 "茅利塔尼亞", "索羅門群島", "墨西哥", "索馬利亞",
                 "摩爾多瓦", "南非", "蒙古", "西班牙", "摩洛哥", "斯里蘭卡",
                 "緬甸", "蘇丹", "納米比亞", "蘇利南", "諾魯", "史瓦濟蘭",
                 "尼泊爾", "瑞典", "荷蘭", "瑞士", "新喀里多尼亞", "敘利亞",
                 "紐西蘭", "坦尚尼亞", "尼日", "泰國", "奈及利亞", "多哥",
                 "挪威", "千里達及托貝哥", "阿曼", "突尼西亞", "巴基斯坦", "土耳其",
                 "巴拿馬", "烏干達", "巴布亞紐幾內亞", "烏克蘭",
                 "巴拉圭", "阿拉伯聯合大公國", "秘魯", "美國", "菲律賓", "烏拉圭",
                 "波蘭", "委內瑞拉", "葡萄牙", "越南", "卡達", "西薩摩亞",
                 "羅馬尼亞", "葉門", "俄羅斯", "尚比亞", "盧安達", "辛巴威",
                 "聖克里斯多福及尼維斯")

    @classmethod
    def secondary_address(cls):
        return cls.numerify(cls.random_element(cls.secondary_address_formats))

    @classmethod
    def building_number(cls):
        return cls.numerify(cls.random_element(cls.building_number_formats))

    @classmethod
    def street_name(cls):
        return cls.random_element(cls.street_names)

    @classmethod
    def city_name(cls):
        return cls.random_element(cls.cities)



# coding=utf-8

from __future__ import unicode_literals

import unittest

from faker import Factory
from email_validator import validate_email


class zh_CN_FactoryTestCase(unittest.TestCase):
    def setUp(self):
        self.factory = Factory.create(locale='zh_CN')

    def test_email(self):
        email = self.factory.email()
        validate_email(email, check_deliverability=False)



from __future__ import unicode_literals
from collections import OrderedDict

from ..en import Provider as AddressProvider


class Provider(AddressProvider):
    city_prefixes = ('North', 'East', 'West', 'South', 'New', 'Lake', 'Port')
    city_suffixes = (
        'town', 'ton', 'land', 'ville', 'berg', 'burgh', 'borough', 'bury', 'view', 'port', 'mouth', 'stad', 'furt',
        'chester', 'mouth', 'fort', 'haven', 'side', 'shire',
    )
    building_number_formats = ('#', '##', '###')
    street_suffixes = (
        'alley', 'avenue', 'branch', 'bridge', 'brook', 'brooks', 'burg', 'burgs', 'bypass', 'camp', 'canyon', 'cape',
        'causeway', 'center', 'centers', 'circle', 'circles', 'cliff', 'cliffs', 'club', 'common', 'corner', 'corners',
        'course', 'court', 'courts', 'cove', 'coves', 'creek', 'crescent', 'crest', 'crossing', 'crossroad', 'curve',
        'dale', 'dam', 'divide', 'drive', 'drive', 'drives', 'estate', 'estates', 'expressway', 'extension',
        'extensions',
        'fall', 'falls', 'ferry', 'field', 'fields', 'flat', 'flats', 'ford', 'fords', 'forest', 'forge', 'forges',
        'fork',
        'forks', 'fort', 'freeway', 'garden', 'gardens', 'gateway', 'glen', 'glens', 'green', 'greens', 'grove',
        'groves',
        'harbor', 'harbors', 'haven', 'heights', 'highway', 'hill', 'hills', 'hollow', 'inlet', 'inlet', 'island',
        'island',
        'islands', 'islands', 'isle', 'isle', 'junction', 'junctions', 'key', 'keys', 'knoll', 'knolls', 'lake',
        'lakes',
        'land', 'landing', 'lane', 'light', 'lights', 'loaf', 'lock', 'locks', 'locks', 'lodge', 'lodge', 'loop',
        'mall',
        'manor', 'manors', 'meadow', 'meadows', 'mews', 'mill', 'mills', 'mission', 'mission', 'motorway', 'mount',
        'mountain', 'mountain', 'mountains', 'mountains', 'neck', 'orchard', 'oval', 'overpass', 'park', 'parks',
        'parkway',
        'parkways', 'pass', 'passage', 'path', 'pike', 'pine', 'pines', 'place', 'plain', 'plains', 'plains', 'plaza',
        'plaza', 'point', 'points', 'port', 'port', 'ports', 'ports', 'prairie', 'prairie', 'radial', 'ramp', 'ranch',
        'rapid', 'rapids', 'rest', 'ridge', 'ridges', 'river', 'road', 'road', 'roads', 'roads', 'route', 'row', 'rue',
        'run', 'shoal', 'shoals', 'shore', 'shores', 'skyway', 'spring', 'springs', 'springs', 'spur', 'spurs',
        'square',
        'square', 'squares', 'squares', 'station', 'station', 'stravenue', 'stravenue', 'stream', 'stream', 'street',
        'street', 'streets', 'summit', 'summit', 'terrace', 'throughway', 'trace', 'track', 'trafficway', 'trail',
        'trail',
        'tunnel', 'tunnel', 'turnpike', 'turnpike', 'underpass', 'union', 'unions', 'valley', 'valleys', 'via',
        'viaduct',
        'view', 'views', 'village', 'village', 'villages', 'ville', 'vista', 'vista', 'walk', 'walks', 'wall', 'way',
        'ways', 'well', 'wells')

    POSTAL_ZONES = (
        'AB', 'AL', 'B' , 'BA', 'BB', 'BD', 'BH', 'BL', 'BN', 'BR',
        'BS', 'BT', 'CA', 'CB', 'CF', 'CH', 'CM', 'CO', 'CR', 'CT',
        'CV', 'CW', 'DA', 'DD', 'DE', 'DG', 'DH', 'DL', 'DN', 'DT',
        'DY', 'E' , 'EC', 'EH', 'EN', 'EX', 'FK', 'FY', 'G' , 'GL',
        'GY', 'GU', 'HA', 'HD', 'HG', 'HP', 'HR', 'HS', 'HU', 'HX',
        'IG', 'IM', 'IP', 'IV', 'JE', 'KA', 'KT', 'KW', 'KY', 'L' ,
        'LA', 'LD', 'LE', 'LL', 'LN', 'LS', 'LU', 'M' , 'ME', 'MK',
        'ML', 'N' , 'NE', 'NG', 'NN', 'NP', 'NR', 'NW', 'OL', 'OX',
        'PA', 'PE', 'PH', 'PL', 'PO', 'PR', 'RG', 'RH', 'RM', 'S' ,
        'SA', 'SE', 'SG', 'SK', 'SL', 'SM', 'SN', 'SO', 'SP', 'SR',
        'SS', 'ST', 'SW', 'SY', 'TA', 'TD', 'TF', 'TN', 'TQ', 'TR',
        'TS', 'TW', 'UB', 'W' , 'WA', 'WC', 'WD', 'WF', 'WN', 'WR',
        'WS', 'WV', 'YO', 'ZE'
    )

    POSTAL_ZONES_ONE_CHAR = [zone for zone in POSTAL_ZONES if len(zone) == 1]
    POSTAL_ZONES_TWO_CHARS = [zone for zone in POSTAL_ZONES if len(zone) == 2]

    postcode_formats = (
        'AN NEE',
        'ANN NEE',
        'PN NEE',
        'PNN NEE',
        'ANC NEE',
        'PND NEE',
    )

    _postcode_sets = OrderedDict((
        (' ', ' '),
        ('N', [str(i) for i in range(0, 10)]),
        ('A', POSTAL_ZONES_ONE_CHAR),
        ('B', 'ABCDEFGHKLMNOPQRSTUVWXY'),
        ('C', 'ABCDEFGHJKSTUW'),
        ('D', 'ABEHMNPRVWXY'),
        ('E', 'ABDEFGHJLNPQRSTUWXYZ'),
        ('P', POSTAL_ZONES_TWO_CHARS),
    ))

    city_formats = (
        '{{city_prefix}} {{first_name}}{{city_suffix}}',
        '{{city_prefix}} {{first_name}}',
        '{{first_name}}{{city_suffix}}',
        '{{last_name}}{{city_suffix}}',
    )
    street_name_formats = (
        '{{first_name}} {{street_suffix}}',
        '{{last_name}} {{street_suffix}}'
    )
    street_address_formats = (
        '{{building_number}} {{street_name}}',
        '{{secondary_address}}\n{{street_name}}',
    )
    address_formats = (
        "{{street_address}}\n{{city}}\n{{postcode}}",
    )
    secondary_address_formats = ('Flat #', 'Flat ##', 'Flat ##?', 'Studio #', 'Studio ##', 'Studio ##?')

    @classmethod
    def postcode(cls):
        """
        See http://web.archive.org/web/20090930140939/http://www.govtalk.gov.uk/gdsc/html/noframes/PostCode-2-1-Release.htm
        """
        postcode = ''
        pattern = cls.random_element(cls.postcode_formats)
        for placeholder in pattern:
            postcode += cls.random_element(cls._postcode_sets[placeholder])
        return postcode

    @classmethod
    def city_prefix(cls):
        return cls.random_element(cls.city_prefixes)

    @classmethod
    def secondary_address(cls):
        return cls.bothify(cls.random_element(cls.secondary_address_formats))



# -*- coding: utf-8 -*-
from __future__ import unicode_literals
from .. import Provider as AddressProvider


class Provider(AddressProvider):

    building_number_formats = ('###', '##', '#')

    postcode_formats = ('#####', )

    city_formats = ('{{city_name}}', )

    street_name_formats = ('{{fruit}}{{street_suffix}}', )

    street_address_formats = ('{{street_name}} {{building_number}}',)

    address_formats = ("{{street_address}}\n{{postcode}} {{city}}", )

    cities = (
        'Akaa', 'Alajärvi', 'Alavus', 'Espoo', 'Forssa', 'Haapajärvi',
        'Haapavesi', 'Hämeenlinna', 'Hamina', 'Hanko', 'Harjavalta',
        'Haukipudas', 'Heinola', 'Helsinki', 'Huittinen', 'Hyvinkää',
        'Iisalmi', 'Ikaalinen', 'Imatra', 'Jakobstad', 'Joensuu', 'Juankoski',
        'Jyväskylä', 'Jämsä', 'Järvenpää', 'Kaarina', 'Kajaani', 'Kalajoki',
        'Kankaanpää', 'Kannus', 'Karkkila', 'Kaskinen', 'Kauhajoki', 'Kauhava',
        'Kauniainen', 'Kemi', 'Kemijärvi', 'Kerava', 'Keuruu', 'Kitee',
        'Kiuruvesi', 'Kokemäki', 'Kokkola', 'Kotka', 'Kouvola', 'Kristinestad',
        'Kuhmo', 'Kuopio', 'Kurikka', 'Kuusamo', 'Lahti', 'Laitila',
        'Lappeenranta', 'Lapua', 'Lieksa', 'Lohja', 'Loimaa', 'Loviisa',
        'Mänttä-Vilppula', 'Mariehamn', 'Mikkeli', 'Naantali', 'Närpes',
        'Nilsiä', 'Nivala', 'Nokia', 'Nurmes', 'Nykarleby', 'Orimattila',
        'Orivesi', 'Oulainen', 'Oulu', 'Outokumpu', 'Paimio', 'Pargas',
        'Parkano', 'Pieksämäki', 'Pori', 'Porvoo', 'Pudasjärvi', 'Pyhäjärvi',
        'Raahe', 'Raseborg', 'Rauma', 'Raisio', 'Riihimäki', 'Rovaniemi',
        'Saarijärvi', 'Salo', 'Sastamala', 'Savonlinna', 'Seinäjoki', 'Siuntio',
        'Somero', 'Suonenjoki', 'Tampere', 'Tornio', 'Turku', 'Ulvila',
        'Uusikaupunki', 'Vaasa', 'Valkeakoski', 'Vantaa', 'Varkaus',
        'Viitasaari', 'Virrat', 'Ylivieska', 'Ylöjärvi', 'Äänekoski', 'Ähtäri',
    )

    countries = (
        'Afganistan', 'Alankomaat', 'Albania', 'Algeria', 'Andorra', 'Angola',
        'Antigua ja Barbuda', 'Argentiina', 'Armenia', 'Australia',
        'Azerbaidžan', 'Bahama', 'Bahrain', 'Bangladesh', 'Barbados', 'Belgia',
        'Belize', 'Benin', 'Bhutan', 'Bolivia', 'Bosnia ja Hertsegovina',
        'Botswana', 'Brasilia', 'Brunei', 'Bulgaria', 'Burkina', 'Faso',
        'Burundi', 'Chile', 'Costa', 'Rica', 'Djibouti', 'Dominica',
        'Dominikaaninen tasavalta', 'Ecuador', 'Egypti', 'El', 'Salvador',
        'Eritrea', 'Espanja', 'Etelä-Afrikka', 'Korean tasavalta',
        'Etelä-Sudan', 'Etiopia', 'Fidži', 'Filippiinit', 'Gabon', 'Gambia',
        'Georgia', 'Ghana', 'Grenada', 'Guatemala', 'Guinea-Bissau', 'Guinea',
        'Guyana', 'Haiti', 'Honduras', 'Indonesia', 'Intia', 'Irak', 'Iran',
        'Irlanti', 'Islanti', 'Israel', 'Italia', 'Itä-Timor', 'Itävalta',
        'Jamaika', 'Japani', 'Jemen', 'Jordania', 'Kambodža', 'Kamerun',
        'Kanada', 'Kap', 'Verde', 'Kazakstan', 'Kenia',
        'Keski-Afrikan tasavalta', 'Kiina', 'Kirgisia', 'Kiribati',
        'Kolumbia', 'Komorit', 'Kongon demokraattinen tasavalta',
        'Kongon tasavalta', 'Kosovo', 'Kreikka', 'Kroatia', 'Kuuba', 'Kuwait',
        'Kypros', 'Laos', 'Latvia', 'Lesotho', 'Libanon', 'Liberia', 'Libya',
        'Liechtenstein', 'Liettua', 'Luxemburg', 'Madagaskar', 'Makedonia',
        'Malawi', 'Malediivit', 'Malesia', 'Mali', 'Malta', 'Marokko',
        'Marshallinsaaret', 'Mauritania', 'Mauritius', 'Meksiko', 'Mikronesia',
        'Moldova', 'Monaco', 'Mongolia', 'Montenegro', 'Mosambik', 'Myanmar',
        'Namibia', 'Nauru', 'Nepal', 'Nicaragua', 'Nigeria', 'Niger', 'Norja',
        'Norsunluurannikko', 'Oman', 'Pakistan', 'Palau', 'Panama',
        'Papua-Uusi-Guinea', 'Paraguay', 'Peru',
        'Korean demokraattinen kansantasavalta', 'Portugali', 'Puola',
        'Päiväntasaajan Guinea', 'Qatar', 'Ranska', 'Romania', 'Ruanda',
        'Ruotsi', 'Saint Kitts ja Nevis', 'Saint Lucia',
        'Saint Vincent ja Grenadiinit', 'Saksa', 'Salomonsaaret', 'Sambia',
        'Samoa', 'San Marino', 'São Tomé ja Príncipe',
        'Saudi-Arabia', 'Senegal', 'Serbia', 'Seychellit', 'Sierra', 'Leone',
        'Singapore', 'Slovakia', 'Slovenia', 'Somalia', 'Sri', 'Lanka', 'Sudan',
        'Suomi', 'Suriname', 'Swazimaa', 'Sveitsi', 'Syyria', 'Tadžikistan',
        'Tansania', 'Tanska', 'Thaimaa', 'Togo', 'Tonga', 'Trinidad ja Tobago',
        'Tšad', 'Tšekki', 'Tunisia', 'Turkki', 'Turkmenistan', 'Tuvalu',
        'Uganda', 'Ukraina', 'Unkari', 'Uruguay', 'Uusi-Seelanti', 'Uzbekistan',
        'Valko-Venäjä', 'Vanuatu', 'Vatikaanivaltio', 'Venezuela', 'Venäjä',
        'Vietnam', 'Viro', 'Yhdistyneet arabiemiirikunnat',
        'Yhdistynyt kuningaskunta', 'Yhdysvallat', 'Zimbabwe',
    )

    states = (
        'Turun ja Porin lääni', 'Uudenmaan ja Hämeen lääni', 'Pohjanmaan lääni',
        'Viipurin ja Savonlinnan lääni', 'Käkisalmen lääni',
        'Savonlinnan ja Kymenkartanon lääni', 'Kymenkartanon ja Savon lääni',
        'Vaasan lääni', 'Oulun lääni', 'Kymenkartanon lääni',
        'Savon ja Karjalan lääni', 'Viipurin lääni', 'Uudenmaan lääni',
        'Hämeen lääni', 'Mikkelin lääni', 'Kuopion lääni', 'Ahvenanmaan lääni',
        'Petsamon lääni', 'Lapin lääni', 'Kymen lääni', 'Keski-Suomen lääni',
        'Pohjois-Karjalan lääni', 'Etelä-Suomen lääni', 'Länsi-Suomen lääni',
        'Itä-Suomen lääni', '', 'Turun ja Porin lääni',
        'Uudenmaan ja Hämeen lääni', 'Pohjanmaan lääni',
        'Viipurin ja Savonlinnan lääni', 'Käkisalmen lääni',
        'Savonlinnan ja Kymenkartanon lääni', 'Kymenkartanon ja Savon lääni',
        'Vaasan lääni', 'Oulun lääni', 'Kymenkartanon lääni',
        'Savon ja Karjalan lääni', 'Viipurin lääni', 'Uudenmaan lääni',
        'Hämeen lääni', 'Mikkelin lääni', 'Kuopion lääni', 'Ahvenanmaan lääni',
        'Petsamon lääni', 'Lapin lääni', 'Kymen lääni', 'Keski-Suomen lääni',
        'Pohjois-Karjalan lääni', 'Etelä-Suomen lääni', 'Länsi-Suomen lääni',
        'Itä-Suomen lääni'
    )

    street_suffixes = ('tie', 'katu', 'polku', 'kuja', 'bulevardi')

    # Using fruits to generate street names, since it doesn't make
    # much grammatical sense to use first names

    fruits = (
        'Ananas', 'Ananaskirsikka', 'Annoona', 'Appelsiini', 'Aprikoosi',
        'Avokado', 'Banaani', 'Cantaloupemeloni', 'Durio', 'Feijoa',
        'Galiameloni', 'Granaattiomena', 'Granadilla', 'Greippi', 'Guava',
        'Hunajameloni', 'Jakkihedelmä', 'Kaki', 'Kaktusviikuna', 'Karambola',
        'Kastanja', 'Keittobanaani', 'Keltainen', 'kiivi', 'Keltapassio',
        'Kiivi', 'Kirsikka', 'Kirsikkaluumu', 'Kiwai', 'Kiwano', 'Kookospähkinä',
        'Kumkvatti', 'Limetti', 'Limkvatti', 'Litsi', 'Longaani', 'Luumu',
        'Mandariini', 'Mango', 'Mangostaani', 'Maracuya', 'Meloni', 'Nashi',
        'Nektariini', 'Omena', 'Papaija', 'Passionhedelmä', 'Persikka', 'Pepino',
        'Pikkusitrukset', 'Pitahaya', 'Pomelo', 'Pähkinä', 'Päärynä',
        'Rambutani', 'Rumeliini', 'Sapodilla', 'Salaki', 'Sitruuna',
        'Sokerimeloni', 'Sweetie', 'Taateli', 'Tamarillo', 'Tomaatti',
        'Verkkomeloni', 'Vesimeloni', 'Viikuna', 'Viinirypäle', 'Ananas',
        'Annoona', 'Appelsiini', 'Aprikoosi', 'Avokado', 'Banaani',
        'Cantaloupemeloni', 'Durio', 'Feijoa', 'Galiameloni', 'Granaattiomena',
        'Granadilla', 'Greippi', 'Guava', 'Hunajameloni', 'Jakkihedelmä', 'Kaki',
        'Kaktusviikuna', 'Karambola', 'Kastanja', 'Keittobanaani', 'Keltapassio',
        'Kiivi', 'Kirsikka', 'Kirsikkaluumu', 'Kiwai', 'Kiwano', 'Kookospähkinä',
        'Kumkvatti', 'Limetti', 'Limkvatti', 'Litsi', 'Longaani', 'Luumu',
        'Mandariini', 'Mango', 'Mangostaani', 'Maracuya', 'Meloni', 'Nashi',
        'Nektariini', 'Omena', 'Papaija', 'Passionhedelmä', 'Persikka', 'Pepino',
        'Pikkusitrukset', 'Pitahaya', 'Pomelo', 'Pähkinä', 'Päärynä',
        'Rambutani', 'Rumeliini', 'Sapodilla', 'Salaki', 'Sitruuna',
        'Sokerimeloni', 'Sweetie', 'Taateli', 'Tamarillo', 'Tomaatti',
        'Verkkomeloni', 'Vesimeloni', 'Viikuna', 'Viinirypäle'
    )

    @classmethod
    def fruit(cls):
        return cls.random_element(cls.fruits)

    @classmethod
    def city_name(cls):
        return cls.random_element(cls.cities)

    @classmethod
    def state(cls):
        return cls.random_element(cls.states)



# coding=utf-8

from __future__ import unicode_literals

import unittest
import re

from faker import Factory
from ukpostcodeparser.parser import parse_uk_postcode


class en_GB_FactoryTestCase(unittest.TestCase):
    def setUp(self):
        self.factory = Factory.create('en_GB')

    def test_en_GB_postcode(self):
        from faker.providers.address.en_GB import Provider
        for i in range(100):
            assert isinstance(parse_uk_postcode(self.factory.postcode()), tuple)



#  -*- coding: utf-8 -*-

from __future__ import unicode_literals

import unittest
import re

from faker import Factory
from faker.providers.company.pt_BR import Provider as CompanyProvider, company_id_checksum
from faker.providers.ssn.pt_BR import Provider, checksum


class pt_BR_FactoryTestCase(unittest.TestCase):
    def setUp(self):
        self.factory = Factory.create('pt_BR')

    def test_pt_BR_ssn_checksum(self):
        self.assertEqual(checksum([8, 8, 2, 8, 2, 1, 6, 5, 2]), 2)
        self.assertEqual(checksum([8, 8, 2, 8, 2, 1, 6, 5, 2, 2]), 1)

    def test_pt_BR_ssn(self):
        for _ in range(100):
            self.assertTrue(re.search(r'^\d{11}$', Provider.ssn()))

    def test_pt_BR_cpf(self):
        for _ in range(100):
            self.assertTrue(re.search(r'\d{3}\.\d{3}\.\d{3}\-\d{2}', Provider.cpf()))

    def test_pt_BR_company_id_checksum(self):
        self.assertEqual(company_id_checksum([9, 4, 9, 5, 3, 4, 4, 1, 0, 0, 0, 1]), [5, 1])
        self.assertEqual(company_id_checksum([1, 6, 0, 0, 4, 6, 3, 9, 0, 0, 0, 1]), [8, 5])

    def test_pt_BR_company_id(self):
        for _ in range(100):
            self.assertTrue(re.search(r'^\d{14}$', CompanyProvider.company_id()))

    def test_pt_BR_cnpj(self):
        for _ in range(100):
            cnpj = CompanyProvider.cnpj()
            self.assertTrue(re.search(r'\d{2}\.\d{3}\.\d{3}/0001-\d{2}', cnpj))



# coding=utf-8
from __future__ import unicode_literals
from .. import Provider as InternetProvider


class Provider(InternetProvider):
    user_name_formats = (
        '{{last_name_female}}.{{first_name_female}}',
        '{{last_name_female}}.{{first_name_female}}',
        '{{last_name_male}}.{{first_name_male}}',
        '{{last_name_male}}.{{first_name_male}}',
        '{{first_name_female}}.{{last_name_female}}',
        '{{first_name_male}}.{{last_name_male}}',
        '{{first_name}}##',
        '?{{last_name}}',
        '?{{last_name}}',
        '?{{last_name}}',
    )

    email_formats = ('{{user_name}}@{{free_email_domain}}', )

    free_email_domains = (
        'zoznam.sk', 'gmail.com', 'centrum.sk', 'post.sk', 'chello.sk', 'pobox.sk', 'szm.sk', 'atlas.sk', 'azet.sk',
        'inmail.sk',
    )

    tlds = ('sk', 'com',)



localized = True

from .. import BaseProvider


class Provider(BaseProvider):
    formats = ('###-###-###',)

    @classmethod
    def phone_number(cls):
        return cls.numerify(cls.random_element(cls.formats))



# coding=utf-8

import bisect
from faker.generator import random

def random_sample():
    return random.uniform(0.0, 1.0)


def cumsum(it):
    total = 0
    for x in it:
        total += x
        yield total


def choice_distribution(a, p):
    assert len(a) == len(p)

    cdf = list(cumsum(p))
    normal = cdf[-1]
    cdf2 = [float(i) / float(normal) for i in cdf]
    uniform_sample = random_sample()
    idx = bisect.bisect_right(cdf2, uniform_sample)

    return a[idx]



# coding=utf-8
from __future__ import unicode_literals
from .. import Provider as BaseProvider


class Provider(BaseProvider):

    @classmethod
    def ssn(cls):
        # Certain numbers are invalid for U.S. SSNs. The area (first 3 digits)
        # cannot be 666 or 900-999. The group number (middle digits) cannot be
        # 00. The serial (last 4 digits) cannot be 0000
        area = BaseProvider.random_int(min=1, max=899)
        if area == 666:
            area += 1
        group = BaseProvider.random_int(1, 99)
        serial = BaseProvider.random_int(1, 9999)

        ssn = "{0:03d}-{1:02d}-{2:04d}".format(area, group, serial)
        return ssn



# coding=utf-8

from __future__ import unicode_literals
from .. import Provider as SsnProvider
from faker.generator import random
import datetime


class Provider(SsnProvider):

    @classmethod
    def ssn(cls):
        """
        Returns a 10 digit Swedish SSN, "Personnummer".

        It consists of 10 digits in the form YYMMDD-SSGQ, where
        YYMMDD is the date of birth, SSS is a serial number
        and Q is a control character (Luhn checksum).

        http://en.wikipedia.org/wiki/Personal_identity_number_(Sweden)
        """
        def _luhn_checksum(number):
            def digits_of(n):
                return [int(d) for d in str(n)]
            digits = digits_of(number)
            odd_digits = digits[-1::-2]
            even_digits = digits[-2::-2]
            checksum = 0
            checksum += sum(odd_digits)
            for d in even_digits:
                checksum += sum(digits_of(d * 2))
            return checksum % 10

        def _calculate_luhn(partial_number):
            check_digit = _luhn_checksum(int(partial_number) * 10)
            return check_digit if check_digit == 0 else 10 - check_digit

        min_age = 18 * 365
        max_age = 90 * 365
        age = datetime.timedelta(days=random.randrange(min_age, max_age))
        birthday = datetime.datetime.now() - age
        pnr_date = birthday.strftime('%y%m%d')
        suffix = str(random.randrange(0, 999)).zfill(3)
        luhn_checksum = str(_calculate_luhn(pnr_date + suffix))
        pnr = '{0}-{1}{2}'.format(pnr_date, suffix, luhn_checksum)

        return pnr



# coding=utf-8
from __future__ import unicode_literals

from datetime import date

from .. import Provider as SsnProvider
from faker.providers.date_time import Provider as DateTimeProvider


class Provider(SsnProvider):
    @classmethod
    def ssn(cls):
        """
        Ukrainian "Реєстраційний номер облікової картки платника податків"
        also known as "Ідентифікаційний номер фізичної особи".
        """
        digits = []

        # Number of days between 1899-12-31 and a birth date
        for digit in str((DateTimeProvider.date_object() -
                          date(1899, 12, 31)).days):
            digits.append(int(digit))

        # Person's sequence number
        for _ in range(4):
            digits.append(cls.random_int(0, 9))

        checksum = (digits[0]*-1 + digits[1]*5 + digits[2]*7 + digits[3]*9 +
                    digits[4]*4 + digits[5]*6 + digits[6]*10 + digits[7]*5 +
                    digits[8]*7)
        # Remainder of a checksum divided by 11 or 1 if it equals to 10
        digits.append(checksum % 11 % 10)

        return ''.join(str(digit) for digit in digits)



# -*- coding: utf-8 -*-
from __future__ import unicode_literals

from .. import Provider as AddressProvider
from faker.generator import random


class Provider(AddressProvider):
    address_formats = (
        '{{prefecture}}{{city}}{{town}}{{chome}}{{ban}}{{gou}}',
        '{{prefecture}}{{city}}{{town}}{{chome}}{{ban}}{{gou}} {{town}}{{building_name}}{{building_number}}',
        '{{prefecture}}{{city}}{{town}}{{chome}}{{ban}}{{gou}} {{building_name}}{{town}}{{building_number}}', )

    building_number_formats = ('###', )

    countries = (
        'アフガニスタン', 'アルバニア', 'アルジェリア', 'アメリカ領サモア', 'アンドラ', 'アンゴラ', 'アンギラ', '南極大陸', 'アンティグアバーブーダ', 'アルゼンチン', 'アルメニア', 'アルバ', 'オーストラリア', 'オーストリア', 'アゼルバイジャン',
        'バハマ', 'バーレーン', 'バングラデシュ', 'バルバドス', 'ベラルーシ', 'ベルギー', 'ベリーズ', 'ベナン', 'バミューダ島', 'ブータン', 'ボリビア', 'ボスニア・ヘルツェゴビナ', 'ボツワナ', 'ブーベ島', 'ブラジル', 'イギリス領インド洋地域', 'イギリス領ヴァージン諸島', 'ブルネイ', 'ブルガリア', 'ブルキナファソ', 'ブルンジ',
        'カンボジア', 'カメルーン', 'カナダ', 'カーボベルデ', 'ケイマン諸島', '中央アフリカ共和国', 'チャド', 'チリ', '中国', 'クリスマス島', 'ココス諸島', 'コロンビア', 'コモロ', 'コンゴ共和国', 'クック諸島', 'コスタリカ', 'コートジボワール', 'クロアチア', 'キューバ', 'キプロス共和国', 'チェコ共和国',
        'デンマーク', 'ジブチ共和国', 'ドミニカ国', 'ドミニカ共和国',
        'エクアドル', 'エジプト', 'エルサルバドル', '赤道ギニア共和国', 'エリトリア', 'エストニア', 'エチオピア',
        'フェロー諸島', 'フォークランド諸島', 'フィジー共和国', 'フィンランド', 'フランス', 'フランス領ギアナ', 'フランス領ポリネシア', 'フランス領極南諸島',
        'ガボン', 'ガンビア', 'グルジア', 'ドイツ', 'ガーナ', 'ジブラルタル', 'ギリシャ', 'グリーンランド', 'グレナダ', 'グアドループ', 'グアム', 'グアテマラ', 'ガーンジー', 'ギニア', 'ギニアビサウ', 'ガイアナ',
        'ハイチ', 'ハード島とマクドナルド諸島', 'バチカン市国', 'ホンジュラス', '香港', 'ハンガリー',
        'アイスランド', 'インド', 'インドネシア', 'イラン', 'イラク', 'アイルランド共和国', 'マン島', 'イスラエル', 'イタリア',
        'ジャマイカ', '日本', 'ジャージー島', 'ヨルダン',
        'カザフスタン', 'ケニア', 'キリバス', '朝鮮', '韓国', 'クウェート', 'キルギス共和国',
        'ラオス人民民主共和国', 'ラトビア', 'レバノン', 'レソト', 'リベリア', 'リビア国', 'リヒテンシュタイン', 'リトアニア', 'ルクセンブルク',
        'マカオ', 'マケドニア共和国', 'マダガスカル', 'マラウィ', 'マレーシア', 'モルディブ', 'マリ', 'マルタ共和国', 'マーシャル諸島', 'マルティニーク', 'モーリタニア・イスラム共和国', 'モーリシャス', 'マヨット', 'メキシコ', 'ミクロネシア連邦', 'モルドバ共和国', 'モナコ公国', 'モンゴル', 'モンテネグロ共和国', 'モントセラト', 'モロッコ', 'モザンビーク', 'ミャンマー',
        'ナミビア', 'ナウル', 'ネパール', 'オランダ領アンティル', 'オランダ', 'ニューカレドニア', 'ニュージーランド', 'ニカラグア', 'ニジェール', 'ナイジェリア', 'ニース', 'ノーフォーク島', '北マリアナ諸島', 'ノルウェー',
        'オマーン',
        'パキスタン', 'パラオ', 'パレスチナ自治区', 'パナマ', 'パプアニューギニア', 'パラグアイ', 'ペルー', 'フィリピン', 'ピトケアン諸島', 'ポーランド', 'ポルトガル', 'プエルトリコ',
        'カタール',
        'レユニオン', 'ルーマニア', 'ロシア', 'ルワンダ',
        'サン・バルテルミー島', 'セントヘレナ', 'セントクリストファー・ネイビス連邦', 'セントルシア', 'セント・マーチン島', 'サンピエール島・ミクロン島', 'セントビンセント・グレナディーン', 'サモア', 'サンマリノ', 'サントメプリンシペ', 'サウジアラビア', 'セネガル', 'セルビア', 'セイシェル', 'シエラレオネ', 'シンガポール', 'スロバキア', 'スロベニア', 'ソロモン諸島', 'ソマリア', '南アフリカ共和国', 'サウスジョージア・サウスサンドウィッチ諸島', 'スペイン', 'スリランカ', 'スーダン', 'スリナム', 'スヴァールバル諸島およびヤンマイエン島', 'スワジランド王国', 'スウェーデン', 'スイス', 'シリア',
        '台湾', 'タジキスタン共和国', 'タンザニア', 'タイ', '東ティモール', 'トーゴ', 'トケラウ', 'トンガ', 'トリニダード・トバゴ', 'チュニジア', 'トルコ', 'トルクメニスタン', 'タークス・カイコス諸島', 'ツバル',
        'ウガンダ', 'ウクライナ', 'アラブ首長国連邦', 'イギリス', 'アメリカ合衆国', '合衆国領有小離島', 'アメリカ領ヴァージン諸島', 'ウルグアイ', 'ウズベキスタン',
        'バヌアツ', 'ベネズエラ', 'ベトナム',
        'ウォリス・フツナ', '西サハラ', 'イエメン', 'ザンビア', 'ジンバブエ',
    )

    prefectures = (
        '北海道', '青森県', '岩手県', '宮城県', '秋田県', '山形県', '福島県', '茨城県', '栃木県', '群馬県',
        '埼玉県', '千葉県', '東京都', '神奈川県', '新潟県', '富山県', '石川県', '福井県', '山梨県', '長野県',
        '岐阜県', '静岡県', '愛知県', '三重県', '滋賀県', '京都府', '大阪府', '兵庫県', '奈良県', '和歌山県',
        '鳥取県', '島根県', '岡山県', '広島県', '山口県', '徳島県', '香川県', '愛媛県', '高知県', '福岡県',
        '佐賀県', '長崎県', '熊本県', '大分県', '宮崎県', '鹿児島県', '沖縄県'
    )

    cities = (
        '八千代市', '我孫子市', '鴨川市', '鎌ケ谷市', '君津市', '富津市', '浦安市', '四街道市', '袖ケ浦市',
        '八街市', '印西市', '白井市', '富里市', '南房総市', '匝瑳市', '香取市', '山武市', 'いすみ市', '大網白里市',
        '印旛郡酒々井町', '印旛郡印旛村', '印旛郡本埜村', '印旛郡栄町', '香取郡神崎町', '香取郡多古町', '香取郡東庄町',
        '山武郡九十九里町', '山武郡芝山町', '山武郡横芝光町', '長生郡一宮町', '長生郡睦沢町', '長生郡長生村',
        '長生郡白子町', '長生郡長柄町', '長生郡長南町', '夷隅郡大多喜町', '夷隅郡御宿町', '安房郡鋸南町', '千代田区',
        '中央区', '港区', '新宿区', '文京区', '台東区', '墨田区', '江東区', '品川区', '目黒区', '大田区',
        '世田谷区', '渋谷区', '中野区', '杉並区', '豊島区', '北区', '荒川区', '板橋区', '練馬区', '足立区',
        '葛飾区', '江戸川区', '八王子市', '立川市', '武蔵野市', '三鷹市', '青梅市', '府中市', '昭島市', '調布市',
        '町田市', '小金井市', '小平市', '日野市', '東村山市', '国分寺市', '国立市', '福生市', '狛江市', '東大和市',
        '清瀬市', '東久留米市', '武蔵村山市', '多摩市', '稲城市', '羽村市', 'あきる野市', '西東京市', '西多摩郡瑞穂町',
        '西多摩郡日の出町', '西多摩郡檜原村', '西多摩郡奥多摩町', '大島町', '利島村', '新島村', '神津島村', '三宅島三宅村',
        '御蔵島村', '八丈島八丈町', '青ヶ島村', '小笠原村', '横浜市鶴見区', '横浜市神奈川区', '横浜市西区', '横浜市中区',
        '横浜市南区', '横浜市保土ケ谷区', '横浜市磯子区', '横浜市金沢区', '横浜市港北区', '横浜市戸塚区', '横浜市港南区',
        '横浜市旭区', '横浜市緑区', '横浜市瀬谷区', '横浜市栄区', '横浜市泉区', '横浜市青葉区', '横浜市都筑区',
        '川崎市川崎区', '川崎市幸区', '川崎市中原区', '川崎市高津区', '川崎市多摩区', '川崎市宮前区'
    )

    towns = (
        '丹勢', '中宮祠', '手岡', '東和町', '所野', '土沢', '独鈷沢', '轟', '土呂部', '中小来川', '長畑', '中鉢石町',
        '中三依', '西小来川', '西川', '日光', '東三島', '東大和町', '蟇沼', '二つ室', '方京', '細竹', '前弥六',
        '前弥六南町', '松浦町', '南赤田', '南郷屋', '美原町', '無栗屋', '睦', '百村', '箭坪', '山中新田', '油井',
        '湯宮', '豊町', '湯本塩原', '横林', '四区町', '渡辺', '氏家', '氏家新田', '卯の里', '小入', '大中', '押上',
        '柿木沢', '柿木沢新田', '鍛冶ケ沢', '上高野', '上吉羽', '木立', '権現堂', '幸手', '下宇和田', '下吉羽', '神明内',
        '外国府間', '千塚', '天神島', '戸島', '中川崎', '長間', '西関宿', '花島', '平須賀', '細野', '松石', '太田ヶ谷',
        '上広谷', '五味ヶ谷', '脚折', '脚折町', '鶴ヶ丘', '羽折町', '藤金', '九段南', '皇居外苑', '麹町', '猿楽町',
        '外神田', '西神田', '隼町', '東神田', '一ツ橋', '日比谷公園', '平河町', '丸の内', '丸の内ＪＰタワー', '四番町',
        '六番町', '明石町', '勝どき', '京橋', '月島', '北青山', '港南', '芝浦', '芝公園', '芝大門', '白金', '白金台',
        '台場', '高輪', '虎ノ門', '虎ノ門虎ノ門ヒルズ森タワー', '大京町', '高田馬場', '箪笥町', '津久戸町', '筑土八幡町',
        '戸塚町', '富久町', '戸山', '秋葉原', '浅草', '浅草橋', '池之端', '今戸', '入谷', '上野公園', '上野桜木',
        '雷門', '北上野', '蔵前', '千束', '台東', '鳥越', '西浅草', '日本堤', '橋場', '花川戸', '東浅草', '東上野',
        '松が谷', '三筋', '三ノ輪', '元浅草', '竜泉', '吾妻橋'
    )

    building_names = (
        'パレス', 'ハイツ', 'コーポ', 'アーバン', 'クレスト', 'パーク', 'シティ', 'シャルム', 'コート',
    )

    @classmethod
    def prefecture(cls):
        """
        :example '東京都'
        """
        return cls.random_element(cls.prefectures)

    @classmethod
    def city(cls):
        """
        :example '台東区'
        """
        return cls.random_element(cls.cities)

    @classmethod
    def town(cls):
        """
        :example '浅草'
        """
        return cls.random_element(cls.towns)

    @classmethod
    def chome(cls):
        """
        :example '1丁目'
        """
        return "%d丁目" % random.randint(1, 42)

    @classmethod
    def ban(cls):
        """
        :example '3番'
        """
        return "%d番" % random.randint(1, 27)

    @classmethod
    def gou(cls):
        """
        :example '10号'
        """
        return "%d号" % random.randint(1, 20)

    @classmethod
    def building_name(cls):
        """
        :example 'コーポ芝浦'
        """
        return cls.random_element(cls.building_names)

    @classmethod
    def zipcode(cls):
        """
        :example '101-1212'
        """
        return "%03d-%04d" % (random.randint(0, 999), random.randint(0, 9999))



# coding=utf-8

from __future__ import unicode_literals

import unittest
import re

from faker import Factory


class no_NO_FactoryTestCase(unittest.TestCase):

    def setUp(self):
        self.factory = Factory.create('no_NO')

    def test_en_GB_postcode(self):
        for i in range(100):
            self.assertTrue(re.match(r'^[0-9]{4}$', self.factory.postcode()))



# coding=utf-8

from __future__ import unicode_literals
from .. import Provider as PersonProvider


class Provider(PersonProvider):
    formats = (
        '{{first_name}} {{last_name}}',
    )

    first_names = (
        'Erik', 'Maria', 'Karl', 'Margareta', 'Lars', 'Anna', 'Gunnar',
        'Elisabet', 'Nils', 'Kristina', 'Sven', 'Karin', 'Lennart', 'Eva',
        'Anders', 'Birgitta', 'Olof', 'Ingrid', 'Per', 'Elisabeth', 'Johan',
        'Linnéa', 'Åke', 'Kerstin', 'Gustaf', 'Ingeborg', 'Bengt', 'Marianne',
        'Bertil', 'Viola', 'Hans', 'Elsa', 'Jan', 'Inger', 'Arne', 'Lena',
        'Göran', 'Ulla', 'Axel', 'Marie', 'Bo', 'Christina', 'Stig', 'Astrid',
        'John', 'Sofia', 'Gustav', 'Rut', 'Ingemar', 'Viktoria', 'Gösta',
        'Märta', 'Peter', 'Anita', 'Mikael', 'Helena', 'Leif', 'Irene', 'Oskar',
        'Gunilla', 'Rolf', 'Margit', 'Ingvar', 'Barbro', 'Vilhelm', 'Ingegerd',
        'Kjell', 'Inga', 'Roland', 'Linnea', 'Ulf', 'Britt', 'Rune', 'Signe',
        'Christer', 'Birgit', 'Mats', 'Siv', 'Carl', 'Ester', 'Stefan',
        'Katarina', 'Bror', 'Ingegärd', 'Magnus', 'Matilda', 'Håkan', 'Cecilia',
        'Emanuel', 'Gunhild', 'Georg', 'Charlotta', 'Fredrik', 'Carina', 'Olov',
        'Gun', 'Kurt', 'Monica', 'Ragnar', 'Susanne', 'Knut', 'Berit', 'Evert',
        'Elin', 'Ivar', 'Sonja', 'Harry', 'Alice', 'Ove', 'Yvonne', 'Björn',
        'Svea', 'Martin', 'Agneta', 'Ernst', 'Greta', 'Einar', 'Gunborg',
        'Allan', 'Maj', 'Thomas', 'Edit', 'Folke', 'Annika', 'Valdemar',
        'Gunvor', 'Birger', 'Karolina', 'Sten', 'Gunnel', 'Torsten', 'Sigrid',
        'Henry', 'Brita', 'Börje', 'Vilhelmina', 'Robert', 'Ellen', 'Tommy',
        'Johanna', 'Arvid', 'Elvira', 'Harald', 'Ulrika', 'Jonas', 'Anette',
        'Roger', 'Gerd', 'Alf', 'Teresia', 'Sigvard', 'Valborg', 'Helge', 'Ann',
        'Yngve', 'Britta', 'Henrik', 'Maj-Britt', 'Edvin', 'Lilly', 'Tage',
        'Åsa', 'Sture', 'Gertrud', 'Tore', 'Aina', 'Artur', 'Dagmar', 'Kent',
        'Ebba', 'Göte', 'Augusta', 'Emil', 'Emilia', 'Bernt', 'Gudrun', 'Hugo',
        'Gerda', 'Hjalmar', 'Solveig', 'Jörgen', 'Agnes', 'Albert', 'Lovisa',
        'Holger', 'Louise', 'Inge', 'Lisa', 'Adolf', 'Josefina', 'Kenneth',
        'Mona', 'Tomas', 'Ruth', 'Verner', 'Hanna', 'Torbjörn', 'Jenny', 'Ture',
        'Eleonora', 'Sune', 'Ragnhild', 'August', 'Lilian', 'Valter', 'Eivor',
        'Uno', 'Hildur', 'Viktor', 'Lisbeth', 'Herbert', 'Stina', 'David',
        'Monika', 'Sigfrid', 'Dagny', 'Otto', 'Helga', 'Edvard', 'Britt-Marie',
        'Alfred', 'Pia', 'Sören', 'Hilda', 'Paul', 'Olga', 'Sixten', 'Ingela',
        'Patrik', 'Ida', 'Hilding', 'Anneli', 'Henning', 'Berta', 'Bernhard',
        'Emma', 'Klas', 'Margaretha', 'Reinhold', 'Marita', 'Krister',
        'Camilla', 'Sigurd', 'Ann-Marie', 'Algot', 'Mary', 'Ivan', 'Alma',
        'Michael', 'Hulda', 'Rudolf', 'Vera', 'Erland', 'Charlotte', 'Albin',
        'Maud', 'Helmer', 'Iris', 'Claes', 'Asta', 'Herman', 'Olivia', 'Alvar',
        'Evy', 'Dan', 'Inga-Lill', 'Gerhard', 'Doris', 'Johannes', 'Ulla-Britt',
        'Evald', 'Helen', 'Gottfrid', 'Erika', 'Ola', 'Hilma', 'Eric', 'Sylvia',
        'Rickard', 'Sara', 'Daniel', 'Hildegard', 'Arnold', 'Frideborg',
        'Frans', 'Irma', 'Mauritz', 'Helene', 'Gert', 'Tyra', 'Valfrid', 'Inez',
        'Teodor', 'Harriet', 'Conny', 'Ottilia', 'Fritz', 'Elna', 'Wilhelm',
        'Amalia', 'Olle', 'Laila', 'Anton', 'Ella', 'Urban', 'Anne', 'Valentin',
        'Annie', 'Josef', 'Lillemor', 'Elof', 'Eugenia', 'William', 'Elsie',
        'Leonard', 'Klara', 'Tord', 'Hillevi', 'Egon', 'Marta', 'Joakim',
        'Iréne', 'Erling', 'Mari', 'Staffan', 'Hedvig', 'Elis', 'Selma',
        'Ronny', 'Anne-Marie', 'Andreas', 'Ann-Christin', 'Mattias',
        'Ann-Charlotte', 'Bert', 'Marie-Louise', 'Eskil', 'Anna-Lisa',
        'Alexander', 'Agda', 'Julius', 'Jeanette', 'Ingmar', 'Malin',
        'Christian', 'Siri', 'Ferdinand', 'Alfrida', 'Jonny', 'Ann-Mari',
        'Benny', 'Frida', 'Richard', 'Majken', 'Jan-Erik', 'Rose-Marie',
        'Lars-Erik', 'Elise', 'Konrad', 'Ingalill', 'Natanael', 'Annette',
        'Ludvig', 'Göta', 'Niklas', 'Paulina', 'Tony', 'Amanda', 'Johnny',
        'Gun-Britt', 'Eugen', 'Alfhild', 'Pär', 'Gulli', 'Morgan', 'Judit',
        'Svante', 'Evelina', 'Fritiof', 'Pernilla', 'Östen', 'Inga-Britt',
        'Karl-Erik', 'Anna-Lena', 'Agne', 'Hjördis', 'Oscar', 'Ann-Britt',
        'Kristian', 'Fredrika', 'Jens', 'Carin', 'Filip', 'Elsy', 'Manfred',
        'Magdalena', 'Curt', 'Mariana', 'Samuel', 'Margot'
    )

    last_names = (
        'Johansson', 'Andersson', 'Karlsson', 'Nilsson', 'Eriksson', 'Larsson',
        'Olsson', 'Persson', 'Svensson', 'Pettersson', 'Gustafsson', 'Jonsson',
        'Jansson', 'Hansson', 'Jönsson', 'Petersson', 'Bengtsson', 'Carlsson',
        'Gustavsson', 'Magnusson', 'Olofsson', 'Lindberg', 'Lindström',
        'Jakobsson', 'Lindgren', 'Axelsson', 'Lundberg', 'Bergström',
        'Lundgren', 'Fredriksson', 'Mattsson', 'Berglund', 'Berg', 'Henriksson',
        'Sandberg', 'Håkansson', 'Danielsson', 'Lindqvist', 'Fransson',
        'Sjöberg', 'Forsberg', 'Johnsson', 'Engström', 'Samuelsson', 'Lundin',
        'Eklund', 'Lind', 'Mårtensson', 'Holm', 'Lundqvist', 'Nyström',
        'Holmberg', 'Isaksson', 'Bergman', 'Söderberg', 'Nordström', 'Nyberg',
        'Eliasson', 'Lundström', 'Björk', 'Arvidsson', 'Gunnarsson', 'Ström',
        'Berggren', 'Månsson', 'Wallin', 'Hermansson', 'Nordin', 'Björklund',
        'Jonasson', 'Andreasson', 'Sundberg', 'Hedlund', 'Sandström', 'Ekström',
        'Holmgren', 'Sjögren', 'Åberg', 'Abrahamsson', 'Öberg', 'Göransson',
        'Hellström', 'Martinsson', 'Strömberg', 'Blom', 'Dahlberg', 'Norberg',
        'Söderström', 'Blomqvist', 'Sundström', 'Löfgren', 'Åkesson', 'Åström',
        'Johannesson', 'Bergqvist', 'Josefsson', 'Ek', 'Adolfsson', 'Börjesson',
        'Lund', 'Ottosson', 'Hallberg', 'Boström', 'Englund', 'Lindholm',
        'Möller', 'Nyman', 'Nygren', 'Palm', 'Sjöström', 'Dahl', 'Viklund',
        'Söderlund', 'Borg', 'Falk', 'Ivarsson', 'Höglund', 'Vikström',
        'Holmström', 'Hedberg', 'Bäckström', 'Davidsson', 'Aronsson', 'Pålsson',
        'Friberg', 'Lindblom', 'Skoglund', 'Björkman', 'Östlund', 'Ekman',
        'Lindahl', 'Strandberg', 'Olausson', 'Rosén', 'Erlandsson', 'Strand',
        'Stenberg', 'Edlund', 'Klasson', 'Haglund', 'Augustsson', 'Holmqvist',
        'Dahlgren', 'Oskarsson', 'Knutsson', 'Moberg', 'Malm', 'Norén',
        'Högberg', 'Dahlström', 'Sundqvist', 'Sundin', 'Von', 'Hedström',
        'Blomberg', 'Franzén', 'Lindén', 'Melin', 'Claesson', 'Alm', 'Boman',
        'Nord', 'Paulsson', 'Sjödin', 'Hedman', 'Kristiansson', 'Wikström',
        'Näslund', 'Berntsson', 'Öhman', 'Lundmark', 'Hagström', 'Ågren',
        'Lindell', 'Molin', 'Roos', 'Lindkvist', 'Lundkvist', 'Svärd', 'Sköld',
        'Ljungberg', 'Lilja', 'Ståhl', 'Lindblad', 'Ericsson', 'Norman',
        'Hellberg', 'Ohlsson', 'Niklasson', 'Ekberg', 'Ljung', 'Alfredsson',
        'Österberg', 'Malmberg', 'Törnqvist', 'Forslund', 'Hedin', 'Edström',
        'Linder', 'Frisk', 'Wahlström', 'Hägglund', 'Skog', 'Bäckman',
        'Emanuelsson', 'Asplund', 'Byström', 'Ahlström', 'Lövgren', 'Marklund',
        'Dahlin', 'Hagberg', 'Simonsson', 'Fors', 'Nordlund', 'Nordqvist',
        'Alexandersson', 'Ljunggren', 'Edvardsson', 'Karlström', 'Brandt',
        'Jacobsson', 'Antonsson', 'Bergkvist', 'Hjalmarsson', 'Ahlberg',
        'Dahlqvist', 'Hjelm', 'Hall', 'Malmström', 'Vilhelmsson', 'Backman',
        'Grahn', 'Wiklund', 'Lindvall', 'Salomonsson', 'Westerberg',
        'Kjellberg', 'Vallin', 'Backlund', 'Östman', 'Vesterlund', 'Westerlund',
        'Granberg', 'Strid', 'Jensen', 'Forsman', 'Torstensson', 'Hult',
        'Hallgren', 'Hellman', 'Almqvist', 'Kristensson', 'Levin', 'Sjöblom',
        'Rydberg', 'Svedberg', 'Jeppsson', 'Hellgren', 'Viberg', 'Ahlgren',
        'Sjöholm', 'Palmqvist', 'Hagman', 'Hägg', 'Kvist', 'Blomgren',
        'Östberg', 'Gabrielsson', 'Israelsson', 'Kristoffersson', 'Wiberg',
        'Malmqvist', 'Vestin', 'Sandin', 'Engman', 'Lundell', 'Westman',
        'Nordgren', 'Broberg', 'Hultgren', 'Rydén', 'Sjöstrand', 'Malmgren',
        'Hansen', 'Lindh', 'Rosengren', 'Bäck', 'Åkerlund', 'Sahlin', 'Hultman',
        'Engberg', 'Holgersson', 'Karlberg', 'Ekholm', 'Lindmark', 'Hallin',
        'Hammar', 'Broman', 'Gren', 'Hammarström', 'Krantz', 'Bertilsson',
        'Svanberg', 'Norling', 'Asp', 'Nylander', 'Bodin', 'Sandgren',
        'Brännström', 'Nielsen', 'Svantesson', 'Svahn', 'Blomkvist', 'Thorén',
        'Ekstrand', 'Bolin', 'Wahlberg', 'Lantz', 'Löf', 'Söderqvist',
        'Westberg', 'Sjölund', 'Andrén', 'Engdahl', 'Ekelund', 'Norrman',
        'Halvarsson', 'Forsgren', 'Henningsson', 'Lindskog', 'Norgren',
        'Granström', 'Nordberg', 'Burman', 'Borgström', 'Vestman', 'Söderholm',
        'Westin', 'Melander', 'Sjöstedt', 'Åsberg', 'Sandell', 'Häggström',
        'Bylund', 'Södergren', 'Lundblad', 'Åslund', 'Elofsson', 'Öman',
        'Haraldsson', 'Forsell', 'Sjölin', 'Lindquist', 'Östling', 'Almgren',
        'Källström', 'Brodin', 'Eklöf', 'Lidén', 'Ahlqvist', 'Lennartsson',
        'Ljungqvist', 'Wall', 'Blixt', 'Landin', 'Rasmusson', 'Thulin',
        'Granlund', 'Nylén', 'Ögren', 'Söderman', 'Lundquist', 'Helgesson',
        'Bohlin', 'Palmgren', 'Kling', 'Nordlander', 'Lindfors', 'Linde',
        'Edman', 'Frank', 'Frid', 'Norlin', 'Flink', 'Ekdahl', 'Bergvall',
        'Rosenqvist', 'Flodin', 'Lundholm', 'Turesson', 'Sundell', 'Robertsson',
        'Sjölander', 'Lundh', 'Lundahl', 'Landström', 'Engvall', 'Bergsten',
        'Ericson', 'Pedersen', 'Zetterberg', 'Widén', 'Liljegren', 'Ahlin',
        'Vestlund', 'Edin', 'Lönn', 'Vestberg', 'Nyqvist', 'Stenström', 'Stark',
        'Wennberg', 'Lidström', 'Brolin', 'Anderberg', 'Sundkvist', 'Matsson',
        'Vesterberg', 'Edberg', 'Skoog', 'Bergstrand', 'Ring', 'Norström',
        'Pihl', 'Olander', 'Stenlund', 'Granath', 'Åman', 'Hjort', 'Åkerström',
        'Werner', 'Hultberg', 'Sten', 'Emilsson', 'Christensson', 'Olovsson',
        'Wahlgren', 'Wester', 'Österlund', 'Holst', 'Högström', 'Roth',
        'Albertsson', 'Grönlund', 'Ahl', 'Einarsson', 'Rask', 'Klang',
        'Westlund', 'Norin', 'Gullberg', 'Fagerström', 'Green', 'Dahlén',
        'Ferm', 'Enström', 'Broström', 'Holmkvist', 'Fält', 'Hallström',
        'Adamsson', 'Åkerman', 'Söder', 'Sjöqvist', 'Viktorsson', 'Åkerblom',
        'Svanström', 'Rehn', 'Holmlund', 'Olin', 'Boberg', 'Rylander',
        'Sandqvist', 'Juhlin', 'Bäcklund', 'Selin', 'Zetterström', 'Wallén',
        'Storm', 'Thunberg', 'Ekvall', 'Hellqvist', 'Molander', 'Lindman',
        'Lindeberg', 'Rundqvist', 'Nordén', 'Törnblom', 'Risberg', 'Brink',
        'Wallgren', 'Bohman', 'Grönberg', 'Åkerberg', 'Bergdahl', 'Modig',
        'Albinsson', 'Östergren', 'Edvinsson'
    )



#  -*- coding: utf-8 -*-

from __future__ import unicode_literals

import unittest
import re

from faker import Factory
from faker.providers.ssn.hr_HR import Provider, checksum


class hr_HR_FactoryTestCase(unittest.TestCase):
    def setUp(self):
        self.factory = Factory.create('hr_HR')

    def test_hr_HR_ssn_checksum(self):
        self.assertEqual(checksum([0, 0, 2, 2, 8, 2, 6, 9, 2, 8]), 9)
        self.assertEqual(checksum([5, 8, 9, 3, 6, 9, 5, 1, 2, 5]), 1)
        self.assertEqual(checksum([5, 7, 8, 0, 2, 0, 3, 4, 2, 3]), 7)
        self.assertEqual(checksum([4, 3, 3, 3, 1, 4, 6, 7, 6, 2]), 2)
        self.assertEqual(checksum([0, 5, 9, 3, 7, 7, 5, 9, 1, 8]), 7)
        self.assertEqual(checksum([7, 1, 1, 4, 9, 9, 1, 2, 4, 1]), 6)

    def test_hr_HR_ssn(self):
        for i in range(100):
            self.assertTrue(re.search(r'^\d{11}$', Provider.ssn()))



from __future__ import unicode_literals
from collections import OrderedDict

from ..en import Provider as AddressProvider
from faker.generator import random


class Provider(AddressProvider):
    city_prefixes = ('North', 'East', 'West', 'South', 'New', 'Lake', 'Port')

    city_suffixes = (
        'town', 'ton', 'land', 'ville', 'berg', 'burgh', 'borough', 'bury', 'view', 'port', 'mouth', 'stad', 'furt',
        'chester', 'mouth', 'fort', 'haven', 'side', 'shire')

    building_number_formats = ('#####', '####', '###')

    street_suffixes = (
        'Alley', 'Avenue', 'Branch', 'Bridge', 'Brook', 'Brooks', 'Burg', 'Burgs', 'Bypass', 'Camp', 'Canyon', 'Cape',
        'Causeway', 'Center', 'Centers', 'Circle', 'Circles', 'Cliff', 'Cliffs', 'Club', 'Common', 'Corner', 'Corners',
        'Course', 'Court', 'Courts', 'Cove', 'Coves', 'Creek', 'Crescent', 'Crest', 'Crossing', 'Crossroad', 'Curve',
        'Dale', 'Dam', 'Divide', 'Drive', 'Drive', 'Drives', 'Estate', 'Estates', 'Expressway', 'Extension',
        'Extensions',
        'Fall', 'Falls', 'Ferry', 'Field', 'Fields', 'Flat', 'Flats', 'Ford', 'Fords', 'Forest', 'Forge', 'Forges',
        'Fork',
        'Forks', 'Fort', 'Freeway', 'Garden', 'Gardens', 'Gateway', 'Glen', 'Glens', 'Green', 'Greens', 'Grove',
        'Groves',
        'Harbor', 'Harbors', 'Haven', 'Heights', 'Highway', 'Hill', 'Hills', 'Hollow', 'Inlet', 'Inlet', 'Island',
        'Island',
        'Islands', 'Islands', 'Isle', 'Isle', 'Junction', 'Junctions', 'Key', 'Keys', 'Knoll', 'Knolls', 'Lake',
        'Lakes',
        'Land', 'Landing', 'Lane', 'Light', 'Lights', 'Loaf', 'Lock', 'Locks', 'Locks', 'Lodge', 'Lodge', 'Loop',
        'Mall',
        'Manor', 'Manors', 'Meadow', 'Meadows', 'Mews', 'Mill', 'Mills', 'Mission', 'Mission', 'Motorway', 'Mount',
        'Mountain', 'Mountain', 'Mountains', 'Mountains', 'Neck', 'Orchard', 'Oval', 'Overpass', 'Park', 'Parks',
        'Parkway',
        'Parkways', 'Pass', 'Passage', 'Path', 'Pike', 'Pine', 'Pines', 'Place', 'Plain', 'Plains', 'Plains', 'Plaza',
        'Plaza', 'Point', 'Points', 'Port', 'Port', 'Ports', 'Ports', 'Prairie', 'Prairie', 'Radial', 'Ramp', 'Ranch',
        'Rapid', 'Rapids', 'Rest', 'Ridge', 'Ridges', 'River', 'Road', 'Road', 'Roads', 'Roads', 'Route', 'Row', 'Rue',
        'Run', 'Shoal', 'Shoals', 'Shore', 'Shores', 'Skyway', 'Spring', 'Springs', 'Springs', 'Spur', 'Spurs',
        'Square',
        'Square', 'Squares', 'Squares', 'Station', 'Station', 'Stravenue', 'Stravenue', 'Stream', 'Stream', 'Street',
        'Street', 'Streets', 'Summit', 'Summit', 'Terrace', 'Throughway', 'Trace', 'Track', 'Trafficway', 'Trail',
        'Trail',
        'Tunnel', 'Tunnel', 'Turnpike', 'Turnpike', 'Underpass', 'Union', 'Unions', 'Valley', 'Valleys', 'Via',
        'Viaduct',
        'View', 'Views', 'Village', 'Village', 'Villages', 'Ville', 'Vista', 'Vista', 'Walk', 'Walks', 'Wall', 'Way',
        'Ways', 'Well', 'Wells')

    postcode_formats = ('#####', '#####-####')

    states = (
        'Alabama', 'Alaska', 'Arizona', 'Arkansas', 'California', 'Colorado',
        'Connecticut', 'Delaware', 'Florida', 'Georgia', 'Hawaii', 'Idaho',
        'Illinois', 'Indiana', 'Iowa', 'Kansas', 'Kentucky', 'Louisiana',
        'Maine', 'Maryland', 'Massachusetts', 'Michigan', 'Minnesota',
        'Mississippi', 'Missouri', 'Montana', 'Nebraska', 'Nevada',
        'New Hampshire', 'New Jersey', 'New Mexico', 'New York',
        'North Carolina', 'North Dakota', 'Ohio', 'Oklahoma', 'Oregon',
        'Pennsylvania', 'Rhode Island', 'South Carolina', 'South Dakota',
        'Tennessee', 'Texas', 'Utah', 'Vermont', 'Virginia', 'Washington',
        'West Virginia', 'Wisconsin', 'Wyoming',
    )
    states_abbr = (
        'AL', 'AK', 'AS', 'AZ', 'AR', 'CA', 'CO', 'CT', 'DE', 'DC', 'FM', 'FL',
        'GA', 'GU', 'HI', 'ID', 'IL', 'IN', 'IA', 'KS', 'KY', 'LA', 'ME', 'MH',
        'MD', 'MA', 'MI', 'MN', 'MS', 'MO', 'MT', 'NE', 'NV', 'NH', 'NJ', 'NM',
        'NY', 'NC', 'ND', 'MP', 'OH', 'OK', 'OR', 'PW', 'PA', 'PR', 'RI', 'SC',
        'SD', 'TN', 'TX', 'UT', 'VT', 'VI', 'VA', 'WA', 'WV', 'WI', 'WY',
    )

    military_state_abbr = ('AE', 'AA', 'AP')

    military_ship_prefix = ('USS', 'USNS', 'USNV', 'USCGC')

    military_apo_format = ("PSC ####, Box ####")

    military_dpo_format = ("Unit #### Box ####")

    city_formats = (
        '{{city_prefix}} {{first_name}}{{city_suffix}}',
        '{{city_prefix}} {{first_name}}',
        '{{first_name}}{{city_suffix}}',
        '{{last_name}}{{city_suffix}}',
    )

    street_name_formats = (
        '{{first_name}} {{street_suffix}}',
        '{{last_name}} {{street_suffix}}'
    )

    street_address_formats = (
        '{{building_number}} {{street_name}}',
        '{{building_number}} {{street_name}} {{secondary_address}}',
    )

    address_formats = (
        "{{street_address}}\n{{city}}, {{state_abbr}} {{postcode}}",
    )

    address_formats = OrderedDict((
        ("{{street_address}}\n{{city}}, {{state_abbr}} {{postcode}}", 25),
        #  military address formatting.
        ("{{military_apo}}\nAPO {{military_state}} {{postcode}}", 1),
        ("{{military_ship}} {{last_name}}\nFPO {{military_state}} {{postcode}}", 1),
        ("{{military_dpo}}\nDPO {{military_state}} {{postcode}}", 1),
    ))

    secondary_address_formats = ('Apt. ###', 'Suite ###')

    @classmethod
    def city_prefix(cls):
        return cls.random_element(cls.city_prefixes)

    @classmethod
    def secondary_address(cls):
        return cls.numerify(cls.random_element(cls.secondary_address_formats))

    @classmethod
    def state(cls):
        return cls.random_element(cls.states)

    @classmethod
    def state_abbr(cls):
        return cls.random_element(cls.states_abbr)

    @classmethod
    def zipcode(cls):
        return "%05d" % random.randint(501, 99950)

    @classmethod
    def zipcode_plus4(cls):
        return "%s-%04d" % (cls.zipcode(), random.randint(1, 9999))

    @classmethod
    def military_ship(cls):
        """
        :example 'USS'
        """
        return cls.random_element(cls.military_ship_prefix)

    @classmethod
    def military_state(cls):
        """
        :example 'APO'
        """
        return cls.random_element(cls.military_state_abbr)

    @classmethod
    def military_apo(cls):
        """
        :example 'PSC 5394 Box 3492
        """
        return cls.numerify(cls.military_apo_format)

    @classmethod
    def military_dpo(cls):
        """
        :example 'Unit 3333 Box 9342'
        """
        return cls.numerify(cls.military_dpo_format)

    # Aliases
    @classmethod
    def postalcode(cls):
        return cls.zipcode()

    @classmethod
    def postalcode_plus4(cls):
        return cls.zipcode_plus4()



# coding=utf-8
from __future__ import unicode_literals
from collections import OrderedDict

from .. import Provider as PersonProvider

class Provider(PersonProvider):
    formats_male = OrderedDict((
        ('{{last_name_male}} {{first_name_male}} {{middle_name_male}}', 0.97),
        ('{{prefix_male}} {{last_name_male}} {{first_name_male}} {{middle_name_male}}', 0.03),
    ))

    formats_female = OrderedDict((
        ('{{last_name_female}} {{first_name_female}} {{middle_name_female}}', 0.97),
        ('{{prefix_female}} {{last_name_female}} {{first_name_female}} {{middle_name_female}}', 0.03),
    ))

    # Using random_element's dictionary weighting means that the
    #     formats = formats_male + formats_female
    # has to be replaced with something dict and python 2.x compatible

    formats = formats_male.copy()
    formats.update(formats_female)

    first_names_male = (
        'Август', 'Авдей', 'Аверкий', 'Аверьян', 'Авксентий', 'Автоном',
        'Агап', 'Агафон', 'Аггей', 'Адам', 'Адриан', 'Азарий',
        'Аким', 'Александр', 'Алексей', 'Амвросий', 'Амос', 'Ананий',
        'Анатолий', 'Андрей', 'Андрон', 'Андроник', 'Аникей', 'Аникита',
        'Анисим', 'Антип', 'Антонин', 'Аполлинарий', 'Аполлон', 'Арефий',
        'Аристарх', 'Аркадий', 'Арсений', 'Артемий', 'Артем', 'Архип',
        'Аскольд', 'Афанасий', 'Афиноген', 'Бажен', 'Богдан', 'Болеслав',
        'Борис', 'Борислав', 'Боян', 'Бронислав', 'Будимир', 'Вадим',
        'Валентин', 'Валерий', 'Валерьян', 'Варлаам', 'Варфоломей', 'Василий',
        'Вацлав', 'Велимир', 'Венедикт', 'Вениамин', 'Викентий', 'Виктор',
        'Викторин', 'Виссарион', 'Виталий', 'Владилен', 'Владлен', 'Владимир',
        'Владислав', 'Влас', 'Всеволод', 'Всемил', 'Всеслав', 'Вышеслав',
        'Вячеслав', 'Гаврила', 'Галактион', 'Гедеон', 'Геннадий', 'Георгий',
        'Герасим', 'Герман', 'Глеб', 'Гордей', 'Гостомысл', 'Гремислав',
        'Григорий', 'Гурий', 'Давыд', 'Данила', 'Дементий', 'Демид',
        'Демьян', 'Денис', 'Дмитрий', 'Добромысл', 'Доброслав', 'Дорофей',
        'Евгений', 'Евграф', 'Евдоким', 'Евлампий', 'Евсей', 'Евстафий',
        'Евстигней', 'Егор', 'Елизар', 'Елисей', 'Емельян', 'Епифан',
        'Еремей', 'Ермил', 'Ермолай', 'Ерофей', 'Ефим', 'Ефрем',
        'Захар', 'Зиновий', 'Зосима', 'Иван', 'Игнатий', 'Игорь',
        'Измаил', 'Изот', 'Изяслав', 'Иларион', 'Илья', 'Иннокентий',
        'Иосиф', 'Ипат', 'Ипатий', 'Ипполит', 'Ираклий', 'Исай',
        'Исидор', 'Казимир', 'Каллистрат', 'Капитон', 'Карл', 'Карп',
        'Касьян', 'Ким', 'Кир', 'Кирилл', 'Клавдий', 'Климент',
        'Кондрат', 'Кондратий', 'Конон', 'Константин', 'Корнил', 'Кузьма',
        'Куприян', 'Лавр', 'Лаврентий', 'Ладимир', 'Ладислав', 'Лазарь',
        'Лев', 'Леон', 'Леонид', 'Леонтий', 'Лонгин', 'Лука',
        'Лукьян', 'Лучезар', 'Любим', 'Любомир', 'Любосмысл', 'Макар',
        'Максим', 'Максимильян', 'Мариан', 'Марк', 'Мартын', 'Мартьян',
        'Матвей', 'Мефодий', 'Мечислав', 'Милан', 'Милен', 'Милий',
        'Милован', 'Мина', 'Мир', 'Мирон', 'Мирослав', 'Митофан',
        'Михаил', 'Михей', 'Модест', 'Моисей', 'Мокей', 'Мстислав',
        'Назар', 'Наркис', 'Натан', 'Наум', 'Нестор', 'Никандр',
        'Никанор', 'Никита', 'Никифор', 'Никодим', 'Николай', 'Никон',
        'Нифонт', 'Олег', 'Олимпий', 'Онуфрий', 'Орест', 'Осип',
        'Остап', 'Остромир', 'Павел', 'Панкратий', 'Панкрат', 'Пантелеймон',
        'Панфил', 'Парамон', 'Парфен', 'Пахом', 'Петр', 'Пимен',
        'Платон', 'Поликарп', 'Порфирий', 'Потап', 'Пров', 'Прокл',
        'Прокофий', 'Прохор', 'Радим', 'Радислав', 'Радован', 'Ратибор',
        'Ратмир', 'Родион', 'Роман', 'Ростислав', 'Рубен', 'Руслан',
        'Рюрик', 'Савва', 'Савватий', 'Савелий', 'Самсон', 'Самуил',
        'Светозар', 'Святополк', 'Святослав', 'Севастьян', 'Селиван', 'Селиверст',
        'Семен', 'Серафим', 'Сергей', 'Сигизмунд', 'Сидор', 'Сила',
        'Силантий', 'Сильвестр', 'Симон', 'Сократ', 'Соломон', 'Софон',
        'Софрон', 'Спартак', 'Спиридон', 'Станимир', 'Станислав', 'Степан',
        'Стоян', 'Тарас', 'Твердислав', 'Творимир', 'Терентий', 'Тимофей',
        'Тимур', 'Тит', 'Тихон', 'Трифон', 'Трофим', 'Ульян',
        'Устин', 'Фадей', 'Федор', 'Федосий', 'Федот', 'Феликс',
        'Феоктист', 'Феофан', 'Ферапонт', 'Филарет', 'Филимон', 'Филипп',
        'Фирс', 'Флорентин', 'Фока', 'Фома', 'Фортунат', 'Фотий',
        'Фрол', 'Харитон', 'Харлампий', 'Христофор', 'Чеслав', 'Эдуард',
        'Эммануил', 'Эмиль', 'Эраст', 'Эрнест', 'Эрнст', 'Ювеналий',
        'Юлиан', 'Юлий', 'Юрий', 'Яков', 'Ян', 'Якуб',
        'Януарий', 'Ярополк', 'Ярослав'
    )

    first_names_female = (
        'Агата', 'Агафья', 'Акулина', 'Алевтина', 'Александра', 'Алина',
        'Алла', 'Анастасия', 'Ангелина', 'Анжела', 'Анжелика', 'Анна',
        'Антонина', 'Валентина', 'Валерия', 'Варвара', 'Василиса', 'Вера',
        'Вероника', 'Виктория', 'Галина', 'Глафира', 'Дарья', 'Евгения',
        'Евдокия', 'Евпраксия', 'Евфросиния', 'Екатерина', 'Елена', 'Елизавета',
        'Жанна', 'Зинаида', 'Зоя', 'Иванна', 'Ираида', 'Ирина',
        'Ия', 'Кира', 'Клавдия', 'Ксения', 'Лариса', 'Лидия',
        'Лора', 'Лукия', 'Любовь', 'Людмила', 'Майя', 'Маргарита',
        'Марина', 'Мария', 'Марфа', 'Милица', 'Надежда', 'Наина',
        'Наталья', 'Нина', 'Нинель', 'Нонна', 'Оксана', 'Октябрина',
        'Олимпиада', 'Ольга', 'Пелагея', 'Полина', 'Прасковья', 'Раиса',
        'Регина', 'Светлана', 'Синклитикия', 'София', 'Таисия', 'Тамара',
        'Татьяна', 'Ульяна', 'Фаина', 'Феврония', 'Фёкла', 'Элеонора', 'Эмилия', 'Юлия'
        )

    first_names = first_names_male + first_names_female

    last_names_male = (
        'Смирнов', 'Иванов', 'Кузнецов', 'Попов', 'Соколов',
        'Лебедев', 'Козлов', 'Новиков', 'Морозов', 'Петров',
        'Волков', 'Соловьев', 'Васильев', 'Зайцев', 'Павлов',
        'Семенов', 'Голубев', 'Виноградов', 'Богданов', 'Воробьев',
        'Федоров', 'Михайлов', 'Беляев', 'Тарасов', 'Белов',
        'Комаров', 'Орлов', 'Киселев', 'Макаров', 'Андреев',
        'Ковалев', 'Ильин', 'Гусев', 'Титов', 'Кузьмин',
        'Кудрявцев', 'Баранов', 'Куликов', 'Алексеев', 'Степанов',
        'Яковлев', 'Сорокин', 'Сергеев', 'Романов', 'Захаров',
        'Борисов', 'Королев', 'Герасимов', 'Пономарев', 'Григорьев',
        'Лазарев', 'Медведев', 'Ершов', 'Никитин', 'Соболев',
        'Рябов', 'Поляков', 'Цветков', 'Данилов', 'Жуков',
        'Фролов', 'Журавлев', 'Николаев', 'Крылов', 'Максимов',
        'Сидоров', 'Осипов', 'Белоусов', 'Федотов', 'Дорофеев',
        'Егоров', 'Матвеев', 'Бобров', 'Дмитриев', 'Калинин',
        'Анисимов', 'Петухов', 'Антонов', 'Тимофеев', 'Никифоров',
        'Веселов', 'Филиппов', 'Марков', 'Большаков', 'Суханов',
        'Миронов', 'Ширяев', 'Александров', 'Коновалов', 'Шестаков',
        'Казаков', 'Ефимов', 'Денисов', 'Громов', 'Фомин',
        'Давыдов', 'Мельников', 'Щербаков', 'Блинов', 'Колесников',
        'Карпов', 'Афанасьев', 'Власов', 'Маслов', 'Исаков',
        'Тихонов', 'Аксенов', 'Гаврилов', 'Родионов', 'Котов',
        'Горбунов', 'Кудряшов', 'Быков', 'Зуев', 'Третьяков',
        'Савельев', 'Панов', 'Рыбаков', 'Суворов', 'Абрамов',
        'Воронов', 'Мухин', 'Архипов', 'Трофимов', 'Мартынов',
        'Емельянов', 'Горшков', 'Чернов', 'Овчинников', 'Селезнев',
        'Панфилов', 'Копылов', 'Михеев', 'Галкин', 'Назаров',
        'Лобанов', 'Лукин', 'Беляков', 'Потапов', 'Некрасов',
        'Хохлов', 'Жданов', 'Наумов', 'Шилов', 'Воронцов',
        'Ермаков', 'Дроздов', 'Игнатьев', 'Савин', 'Логинов',
        'Сафонов', 'Капустин', 'Кириллов', 'Моисеев', 'Елисеев',
        'Кошелев', 'Костин', 'Горбачев', 'Орехов', 'Ефремов',
        'Исаев', 'Евдокимов', 'Калашников', 'Кабанов', 'Носков',
        'Юдин', 'Кулагин', 'Лапин', 'Прохоров', 'Нестеров',
        'Харитонов', 'Агафонов', 'Муравьев', 'Ларионов', 'Федосеев',
        'Зимин', 'Пахомов', 'Шубин', 'Игнатов', 'Филатов',
        'Крюков', 'Рогов', 'Кулаков', 'Терентьев', 'Молчанов',
        'Владимиров', 'Артемьев', 'Гурьев', 'Зиновьев', 'Гришин',
        'Кононов', 'Дементьев', 'Ситников', 'Симонов', 'Мишин',
        'Фадеев', 'Комиссаров', 'Мамонтов', 'Носов', 'Гуляев',
        'Шаров', 'Устинов', 'Вишняков', 'Евсеев', 'Лаврентьев',
        'Брагин', 'Константинов', 'Корнилов', 'Авдеев', 'Зыков',
        'Бирюков', 'Шарапов', 'Никонов', 'Щукин', 'Дьячков',
        'Одинцов', 'Сазонов', 'Якушев', 'Красильников', 'Гордеев',
        'Самойлов', 'Князев', 'Беспалов', 'Уваров', 'Шашков',
        'Бобылев', 'Доронин', 'Белозеров', 'Рожков', 'Самсонов',
        'Мясников', 'Лихачев', 'Буров', 'Сысоев', 'Фомичев',
        'Русаков', 'Стрелков', 'Гущин', 'Тетерин', 'Колобов',
        'Субботин', 'Фокин', 'Блохин', 'Селиверстов', 'Пестов',
        'Кондратьев', 'Силин', 'Меркушев', 'Лыткин', 'Туров'
    )

    last_names_female = (
        'Смирнова', 'Иванова', 'Кузнецова', 'Попова', 'Соколова',
        'Лебедева', 'Козлова', 'Новикова', 'Морозова', 'Петрова', 'Волкова',
        'Соловьева', 'Васильева', 'Зайцева', 'Павлова', 'Семенова',
        'Голубева', 'Виноградова', 'Богданова', 'Воробьева', 'Федорова',
        'Михайлова', 'Беляева', 'Тарасова', 'Белова', 'Комарова', 'Орлова',
        'Киселева', 'Макарова', 'Андреева', 'Ковалева', 'Ильина', 'Гусева',
        'Титова', 'Кузьмина', 'Кудрявцева', 'Баранова', 'Куликова',
        'Алексеева', 'Степанова', 'Яковлева', 'Сорокина', 'Сергеева',
        'Романова', 'Захарова', 'Борисова', 'Королева', 'Герасимова',
        'Пономарева', 'Григорьева', 'Лазарева', 'Медведева', 'Ершова',
        'Никитина', 'Соболева', 'Рябова', 'Полякова', 'Цветкова', 'Данилова',
        'Жукова', 'Фролова', 'Журавлева', 'Николаева', 'Крылова', 'Максимова',
        'Сидорова', 'Осипова', 'Белоусова', 'Федотова', 'Дорофеева',
        'Егорова', 'Матвеева', 'Боброва', 'Дмитриева', 'Калинина',
        'Анисимова', 'Петухова', 'Антонова', 'Тимофеева', 'Никифорова',
        'Веселова', 'Филиппова', 'Маркова', 'Большакова', 'Суханова',
        'Миронова', 'Ширяева', 'Александрова', 'Коновалова', 'Шестакова',
        'Казакова', 'Ефимова', 'Денисова', 'Громова', 'Фомина', 'Давыдова',
        'Мельникова', 'Щербакова', 'Блинова', 'Колесникова', 'Карпова',
        'Афанасьева', 'Власова', 'Маслова', 'Исакова', 'Тихонова', 'Аксенова',
        'Гаврилова', 'Родионова', 'Котова', 'Горбунова', 'Кудряшова',
        'Быкова', 'Зуева', 'Третьякова', 'Савельева', 'Панова', 'Рыбакова',
        'Суворова', 'Абрамова', 'Воронова', 'Мухина', 'Архипова', 'Трофимова',
        'Мартынова', 'Емельянова', 'Горшкова', 'Чернова', 'Овчинникова',
        'Селезнева', 'Панфилова', 'Копылова', 'Михеева', 'Галкина',
        'Назарова', 'Лобанова', 'Лукина', 'Белякова', 'Потапова', 'Некрасова',
        'Хохлова', 'Жданова', 'Наумова', 'Шилова', 'Воронцова', 'Ермакова',
        'Дроздова', 'Игнатьева', 'Савина', 'Логинова', 'Сафонова',
        'Капустина', 'Кириллова', 'Моисеева', 'Елисеева', 'Кошелева',
        'Костина', 'Горбачева', 'Орехова', 'Ефремова', 'Исаева', 'Евдокимова',
        'Калашникова', 'Кабанова', 'Носкова', 'Юдина', 'Кулагина', 'Лапина',
        'Прохорова', 'Нестерова', 'Харитонова', 'Агафонова', 'Муравьева',
        'Ларионова', 'Федосеева', 'Зимина', 'Пахомова', 'Шубина', 'Игнатова',
        'Филатова', 'Крюкова', 'Рогова', 'Кулакова', 'Терентьева',
        'Молчанова', 'Владимирова', 'Артемьева', 'Гурьева', 'Зиновьева',
        'Гришина', 'Кононова', 'Дементьева', 'Ситникова', 'Симонова',
        'Мишина', 'Фадеева', 'Комиссарова', 'Мамонтова', 'Носова', 'Гуляева',
        'Шарова', 'Устинова', 'Вишнякова', 'Евсеева', 'Лаврентьева',
        'Брагина', 'Константинова', 'Корнилова', 'Авдеева', 'Зыкова',
        'Бирюкова', 'Шарапова', 'Никонова', 'Щукина', 'Дьячкова', 'Одинцова',
        'Сазонова', 'Якушева', 'Красильникова', 'Гордеева', 'Самойлова',
        'Князева', 'Беспалова', 'Уварова', 'Шашкова', 'Бобылева', 'Доронина',
        'Белозерова', 'Рожкова', 'Самсонова', 'Мясникова', 'Лихачева',
        'Бурова', 'Сысоева', 'Фомичева', 'Русакова', 'Стрелкова', 'Гущина',
        'Тетерина', 'Колобова', 'Субботина', 'Фокина', 'Блохина',
        'Селиверстова', 'Пестова', 'Кондратьева', 'Силина', 'Меркушева',
        'Лыткина', 'Турова'
    )

    last_names = last_names_male + last_names_female

    middle_names_male = (
        'Ааронович', 'Абрамович', 'Августович', 'Авдеевич', 'Аверьянович',
        'Адамович', 'Адрианович', 'Аксёнович', 'Александрович', 'Алексеевич',
        'Анатольевич', 'Андреевич', 'Анисимович', 'Антипович', 'Антонович',
        'Ануфриевич', 'Арсенович', 'Арсеньевич', 'Артёмович', 'Артемьевич',
        'Артурович', 'Архипович', 'Афанасьевич', 'Бенедиктович', 'Богданович',
        'Бориславич', 'Бориславович', 'Борисович', 'Брониславович',
        'Валентинович', 'Валерианович', 'Валерьевич', 'Валерьянович',
        'Васильевич', 'Венедиктович', 'Викентьевич', 'Викторович', 'Виленович',
        'Вилорович', 'Витальевич', 'Владиленович', 'Владиславович',
        'Владленович', 'Власович', 'Всеволодович', 'Вячеславович',
        'Гавриилович', 'Гаврилович', 'Геннадиевич', 'Георгиевич', 'Герасимович',
        'Германович', 'Гертрудович', 'Глебович', 'Гордеевич', 'Григорьевич',
        'Гурьевич', 'Давидович', 'Давыдович', 'Даниилович', 'Данилович',
        'Демидович', 'Демьянович', 'Денисович', 'Димитриевич', 'Дмитриевич',
        'Дорофеевич', 'Евсеевич', 'Евстигнеевич', 'Егорович', 'Елизарович',
        'Елисеевич', 'Еремеевич', 'Ермилович', 'Ермолаевич', 'Ерофеевич',
        'Ефимович', 'Ефимьевич', 'Ефремович', 'Ефстафьевич', 'Жанович',
        'Жоресович', 'Захарьевич', 'Зиновьевич', 'Игнатович', 'Игнатьевич',
        'Игоревич', 'Измаилович', 'Изотович', 'Иларионовичх', 'Ильич',
        'Ильясович', 'Иосипович', 'Иосифович', 'Исидорович', 'Марсович',
        'Матвеевич', 'Тарасович', 'Теймуразович', 'Терентьевич', 'Тимурович',
        'Тихонович', 'Трифонович', 'Трофимович', 'Устинович', 'Фадеевич',
        'Фёдорович', 'Федосеевич', 'Федосьевич', 'Федотович', 'Феликсович',
        'Феодосьевич', 'Феоктистович', 'Феофанович', 'Филатович', 'Филимонович',
        'Филиппович', 'Фокич', 'Фомич', 'Фролович', 'Харитонович', 'Харламович',
        'Харлампович', 'Харлампьевич', 'Чеславович', 'Эдгардович', 'Эдгарович',
        'Эдуардович', 'Юлианович', 'Юльевич', 'Яковлевич', 'Якубович',
        'Ярославович'
    )

    middle_names_female = (
        'Александровна', 'Андреевна', 'Архиповна', 'Алексеевна', 'Антоновна',
        'Аскольдовна', 'Альбертовна', 'Аркадьевна', 'Афанасьевна',
        'Анатольевна', 'Артемовна', 'Богдановна', 'Болеславовна', 'Борисовна',
        'Вадимовна', 'Васильевна', 'Владимировна', 'Валентиновна',
        'Вениаминовна', 'Владиславовна', 'Валериевна', 'Викторовна',
        'Вячеславовна', 'Геннадиевна', 'Георгиевна', 'Геннадьевна',
        'Григорьевна', 'Даниловна', 'Дмитриевна', 'Евгеньевна', 'Егоровны',
        'Егоровна', 'Ефимовна', 'Ждановна', 'Захаровна', 'Ивановна', 'Игоревна',
        'Ильинична', 'Кирилловна', 'Кузминична', 'Константиновна',
        'Кузьминична', 'Леонидовна', 'Леоновна', 'Львовна', 'Макаровна',
        'Матвеевна', 'Михайловна', 'Максимовна', 'Мироновна', 'Натановна',
        'Никифоровна', 'Ниловна', 'Наумовна', 'Николаевна', 'Олеговна',
        'Оскаровна', 'Павловна', 'Петровна', 'Робертовна', 'Рубеновна',
        'Руслановна', 'Романовна', 'Рудольфовна', 'Святославовна', 'Сергеевна',
        'Степановна', 'Семеновна', 'Станиславовна', 'Тарасовна', 'Тимофеевна',
        'Тимуровна', 'Федоровна', 'Феликсовна', 'Филипповна', 'Харитоновна',
        'Эдуардовна', 'Эльдаровна', 'Юльевна', 'Юрьевна', 'Яковлевна'
    )

    middle_names = middle_names_male + middle_names_female

    prefixes_male = ('г-н.', 'тов.')

    prefixes_female = ('г-жа', 'тов.')

    @classmethod
    def middle_name(cls):
        return cls.random_element(cls.middle_names)

    @classmethod
    def middle_name_male(cls):
        if hasattr(cls, 'middle_names_male'):
            return cls.random_element(cls.middle_names_male)
        return cls.middle_name()

    @classmethod
    def middle_name_female(cls):
        if hasattr(cls, 'middle_names_female'):
            return cls.random_element(cls.middle_names_female)
        return cls.middle_name()



localized = True
default_locale = 'la'

from .. import BaseProvider


class Provider(BaseProvider):
    @classmethod
    def word(cls):
        """
        Generate a random word
        :example 'lorem'
        """
        return cls.random_element(cls.word_list)

    @classmethod
    def words(cls, nb=3):
        """
        Generate an array of random words
        :example array('Lorem', 'ipsum', 'dolor')
        :param nb how many words to return
        """
        return [cls.word() for _ in range(0, nb)]

    @classmethod
    def sentence(cls, nb_words=6, variable_nb_words=True):
        """
        Generate a random sentence
        :example 'Lorem ipsum dolor sit amet.'
        :param nb_words around how many words the sentence should contain
        :param variable_nb_words set to false if you want exactly $nbWords returned,
            otherwise $nbWords may vary by +/-40% with a minimum of 1
        """
        if nb_words <= 0:
            return ''

        if variable_nb_words:
            nb_words = cls.randomize_nb_elements(nb_words)

        words = cls.words(nb_words)
        words[0] = words[0].title()

        return " ".join(words) + '.'

    @classmethod
    def sentences(cls, nb=3):
        """
        Generate an array of sentences
        :example array('Lorem ipsum dolor sit amet.', 'Consectetur adipisicing eli.')
        :param nb how many sentences to return
        :return list
        """
        return [cls.sentence() for _ in range(0, nb)]

    @classmethod
    def paragraph(cls, nb_sentences=3, variable_nb_sentences=True):
        """
        Generate a single paragraph
        :example 'Sapiente sunt omnis. Ut pariatur ad autem ducimus et. Voluptas rem voluptas sint modi dolorem amet.'
        :param nb_sentences around how many sentences the paragraph should contain
        :param variable_nb_sentences set to false if you want exactly $nbSentences returned,
            otherwise $nbSentences may vary by +/-40% with a minimum of 1
        :return string
        """
        if nb_sentences <= 0:
            return ''

        if variable_nb_sentences:
            nb_sentences = cls.randomize_nb_elements(nb_sentences)

        return " ".join(cls.sentences(nb_sentences))

    @classmethod
    def paragraphs(cls, nb=3):
        """
        Generate an array of paragraphs
        :example array($paragraph1, $paragraph2, $paragraph3)
        :param nb how many paragraphs to return
        :return array
        """
        return [cls.paragraph() for _ in range(0, nb)]

    @classmethod
    def text(cls, max_nb_chars=200):
        """
        Generate a text string.
        Depending on the $maxNbChars, returns a string made of words, sentences, or paragraphs.
        :example 'Sapiente sunt omnis. Ut pariatur ad autem ducimus et. Voluptas rem voluptas sint modi dolorem amet.'
        :param max_nb_chars Maximum number of characters the text should contain (minimum 5)
        :return string
        """
        text = []
        if max_nb_chars < 5:
            raise ValueError('text() can only generate text of at least 5 characters')

        if max_nb_chars < 25:
            # join words
            while not text:
                size = 0
                # determine how many words are needed to reach the $max_nb_chars once;
                while size < max_nb_chars:
                    word = (' ' if size else '') + cls.word()
                    text.append(word)
                    size += len(word)
                text.pop()
            text[0] = text[0][0].upper() + text[0][1:]
            last_index = len(text) - 1
            text[last_index] += '.'
        elif max_nb_chars < 100:
            # join sentences
            while not text:
                size = 0
                # determine how many sentences are needed to reach the $max_nb_chars once
                while size < max_nb_chars:
                    sentence = (' ' if size else '') + cls.sentence()
                    text.append(sentence)
                    size += len(sentence)
                text.pop()
        else:
            # join paragraphs
            while not text:
                size = 0
                # determine how many paragraphs are needed to reach the $max_nb_chars once
                while size < max_nb_chars:
                    paragraph = ('\n' if size else '') + cls.paragraph()
                    text.append(paragraph)
                    size += len(paragraph)
                text.pop()

        return "".join(text)



#!/usr/bin/env python
# coding=utf-8

import os
import io

from setuptools import setup, find_packages

here = os.path.abspath(os.path.dirname(__file__))
README = io.open(os.path.join(here, 'README.rst'), encoding="utf8").read()


version = '0.7.7'

# this module can be zip-safe if the zipimporter implements iter_modules or if
# pkgutil.iter_importer_modules has registered a dispatch for the zipimporter.
try:
    import pkgutil
    import zipimport
    zip_safe = hasattr(zipimport.zipimporter, "iter_modules") or \
        zipimport.zipimporter in pkgutil.iter_importer_modules.registry.keys()
except (ImportError, AttributeError):
    zip_safe = False

setup(
    name='Faker',
    version=version,
    description="Faker is a Python package that generates fake data for you.",
    long_description=README,
    entry_points={
        'console_scripts': ['faker=faker.cli:execute_from_command_line'],
    },
    classifiers=[
        # See https://pypi.python.org/pypi?%3Aaction=list_classifiers
        'Development Status :: 3 - Alpha',
        'Environment :: Console',
        'Intended Audience :: Developers',
        'Programming Language :: Python',
        'Programming Language :: Python :: 2',
        'Programming Language :: Python :: 2.7',
        'Programming Language :: Python :: 3',
        'Programming Language :: Python :: 3.4',
        'Programming Language :: Python :: 3.5',
        'Topic :: Software Development :: Libraries :: Python Modules',
        'Topic :: Software Development :: Testing',
        'Topic :: Utilities',
        'License :: OSI Approved :: MIT License'
    ],
    keywords='faker fixtures data test mock generator',
    author='joke2k',
    author_email='joke2k@gmail.com',
    url='https://github.com/joke2k/faker',
    license='MIT License',
    packages=find_packages(exclude=("docs",)),
    platforms=["any"],
    test_suite='faker.tests',
    zip_safe=zip_safe,
    install_requires=[
        "python-dateutil>=2.4",
        "six",
    ],
    extras_require={
        ':python_version=="2.7"': [
            'ipaddress',
        ],
        ':python_version=="3.0"': [
            'importlib',
        ],
        ':python_version=="3.2"': [
            'ipaddress',
        ],
    }
)



# coding=utf-8
from __future__ import unicode_literals
from .. import Provider as SsnProvider
from faker.generator import random


class Provider(SsnProvider):

    # in order to create a valid SIN we need to provide a number that passes a simple modified Luhn Algorithmn checksum
    # this function essentially reverses the checksum steps to create a random valid SIN (Social Insurance Number)
    @classmethod
    def ssn(cls):

        # create an array of 8 elements initialized randomly
        digits = random.sample(range(10), 8)

        # All of the digits must sum to a multiple of 10.
        # sum the first 8 and set 9th to the value to get to a multiple of 10
        digits.append(10 - (sum(digits) % 10))

        # digits is now the digital root of the number we want multiplied by the magic number 121 212 121
        # reverse the multiplication which occurred on every other element
        for i in range(1, len(digits), 2):
            if digits[i] % 2 == 0:
                digits[i] = (digits[i] / 2)
            else:
                digits[i] = (digits[i] + 9) / 2

        # build the resulting SIN string
        sin = ""
        for i in range(0, len(digits), 1):
            sin += str(digits[i])
            # add a space to make it conform to normal standards in Canada
            if i % 3 == 2:
                sin += " "

        # finally return our random but valid SIN
        return sin



# coding=utf-8
localized = True

from .. import BaseProvider


class Provider(BaseProvider):
    jobs = (
        "Academic librarian",
        "Accommodation manager",
        "Accountant, chartered",
        "Accountant, chartered certified",
        "Accountant, chartered management",
        "Accountant, chartered public finance",
        "Accounting technician",
        "Actor",
        "Actuary",
        "Acupuncturist",
        "Administrator",
        "Administrator, arts",
        "Administrator, charities/voluntary organisations",
        "Administrator, Civil Service",
        "Administrator, education",
        "Administrator, local government",
        "Administrator, sports",
        "Adult guidance worker",
        "Adult nurse",
        "Advertising account executive",
        "Advertising account planner",
        "Advertising art director",
        "Advertising copywriter",
        "Advice worker",
        "Aeronautical engineer",
        "Agricultural consultant",
        "Agricultural engineer",
        "Aid worker",
        "Air broker",
        "Air cabin crew",
        "Air traffic controller",
        "Airline pilot",
        "Ambulance person",
        "Amenity horticulturist",
        "Analytical chemist",
        "Animal nutritionist",
        "Animal technologist",
        "Animator",
        "Applications developer",
        "Arboriculturist",
        "Archaeologist",
        "Architect",
        "Architectural technologist",
        "Archivist",
        "Armed forces logistics/support/administrative officer",
        "Armed forces operational officer",
        "Armed forces technical officer",
        "Armed forces training and education officer",
        "Art gallery manager",
        "Art therapist",
        "Artist",
        "Arts administrator",
        "Arts development officer",
        "Associate Professor",
        "Astronomer",
        "Audiological scientist",
        "Automotive engineer",
        "Banker",
        "Barista",
        "Barrister",
        "Barrister's clerk",
        "Best boy",
        "Biochemist, clinical",
        "Biomedical engineer",
        "Biomedical scientist",
        "Bonds trader",
        "Bookseller",
        "Brewing technologist",
        "Broadcast engineer",
        "Broadcast journalist",
        "Broadcast presenter",
        "Building control surveyor",
        "Building services engineer",
        "Building surveyor",
        "Buyer, industrial",
        "Buyer, retail",
        "Cabin crew",
        "Call centre manager",
        "Camera operator",
        "Careers adviser",
        "Careers information officer",
        "Cartographer",
        "Catering manager",
        "Ceramics designer",
        "Charity fundraiser",
        "Charity officer",
        "Chartered accountant",
        "Chartered certified accountant",
        "Chartered legal executive (England and Wales)",
        "Chartered loss adjuster",
        "Chartered management accountant",
        "Chartered public finance accountant",
        "Chemical engineer",
        "Chemist, analytical",
        "Chief Executive Officer",
        "Chief Financial Officer",
        "Chief Marketing Officer",
        "Chief of Staff",
        "Chief Operating Officer",
        "Chief Strategy Officer",
        "Chief Technology Officer",
        "Child psychotherapist",
        "Chiropodist",
        "Chiropractor",
        "Civil engineer, consulting",
        "Civil engineer, contracting",
        "Civil Service administrator",
        "Civil Service fast streamer",
        "Claims inspector/assessor",
        "Clinical biochemist",
        "Clinical cytogeneticist",
        "Clinical embryologist",
        "Clinical molecular geneticist",
        "Clinical psychologist",
        "Clinical research associate",
        "Clinical scientist, histocompatibility and immunogenetics",
        "Clothing/textile technologist",
        "Colour technologist",
        "Commercial art gallery manager",
        "Commercial horticulturist",
        "Commercial/residential surveyor",
        "Commissioning editor",
        "Communications engineer",
        "Community arts worker",
        "Community development worker",
        "Community education officer",
        "Community pharmacist",
        "Company secretary",
        "Comptroller",
        "Computer games developer",
        "Conference centre manager",
        "Conservation officer, historic buildings",
        "Conservation officer, nature",
        "Conservator, furniture",
        "Conservator, museum/gallery",
        "Consulting civil engineer",
        "Contracting civil engineer",
        "Contractor",
        "Control and instrumentation engineer",
        "Copy",
        "Copywriter, advertising",
        "Corporate investment banker",
        "Corporate treasurer",
        "Counselling psychologist",
        "Counsellor",
        "Curator",
        "Customer service manager",
        "Cytogeneticist",
        "Dance movement psychotherapist",
        "Dancer",
        "Data processing manager",
        "Data scientist",
        "Database administrator",
        "Dealer",
        "Dentist",
        "Designer, blown glass/stained glass",
        "Designer, ceramics/pottery",
        "Designer, exhibition/display",
        "Designer, fashion/clothing",
        "Designer, furniture",
        "Designer, graphic",
        "Designer, industrial/product",
        "Designer, interior/spatial",
        "Designer, jewellery",
        "Designer, multimedia",
        "Designer, television/film set",
        "Designer, textile",
        "Development worker, community",
        "Development worker, international aid",
        "Diagnostic radiographer",
        "Dietitian",
        "Diplomatic Services operational officer",
        "Dispensing optician",
        "Doctor, general practice",
        "Doctor, hospital",
        "Dramatherapist",
        "Drilling engineer",
        "Early years teacher",
        "Ecologist",
        "Economist",
        "Editor, commissioning",
        "Editor, film/video",
        "Editor, magazine features",
        "Editorial assistant",
        "Education administrator",
        "Education officer, community",
        "Education officer, environmental",
        "Education officer, museum",
        "Educational psychologist",
        "Electrical engineer",
        "Electronics engineer",
        "Embryologist, clinical",
        "Emergency planning/management officer",
        "Energy engineer",
        "Energy manager",
        "Engineer, aeronautical",
        "Engineer, agricultural",
        "Engineer, automotive",
        "Engineer, biomedical",
        "Engineer, broadcasting (operations)",
        "Engineer, building services",
        "Engineer, chemical",
        "Engineer, civil (consulting)",
        "Engineer, civil (contracting)",
        "Engineer, communications",
        "Engineer, control and instrumentation",
        "Engineer, drilling",
        "Engineer, electrical",
        "Engineer, electronics",
        "Engineer, energy",
        "Engineer, land",
        "Engineer, maintenance",
        "Engineer, maintenance (IT)",
        "Engineer, manufacturing",
        "Engineer, manufacturing systems",
        "Engineer, materials",
        "Engineer, mining",
        "Engineer, petroleum",
        "Engineer, production",
        "Engineer, site",
        "Engineer, structural",
        "Engineer, technical sales",
        "Engineer, water",
        "Engineering geologist",
        "English as a foreign language teacher",
        "English as a second language teacher",
        "Environmental consultant",
        "Environmental education officer",
        "Environmental health practitioner",
        "Environmental manager",
        "Equality and diversity officer",
        "Equities trader",
        "Ergonomist",
        "Estate agent",
        "Estate manager/land agent",
        "Event organiser",
        "Exercise physiologist",
        "Exhibition designer",
        "Exhibitions officer, museum/gallery",
        "Facilities manager",
        "Farm manager",
        "Fashion designer",
        "Fast food restaurant manager",
        "Field seismologist",
        "Field trials officer",
        "Film/video editor",
        "Financial adviser",
        "Financial controller",
        "Financial manager",
        "Financial planner",
        "Financial risk analyst",
        "Financial trader",
        "Fine artist",
        "Firefighter",
        "Fish farm manager",
        "Fisheries officer",
        "Fitness centre manager",
        "Food technologist",
        "Forensic psychologist",
        "Forensic scientist",
        "Forest/woodland manager",
        "Freight forwarder",
        "Furniture conservator/restorer",
        "Furniture designer",
        "Further education lecturer",
        "Futures trader",
        "Gaffer",
        "Games developer",
        "Garment/textile technologist",
        "General practice doctor",
        "Geneticist, molecular",
        "Geochemist",
        "Geographical information systems officer",
        "Geologist, engineering",
        "Geologist, wellsite",
        "Geophysical data processor",
        "Geophysicist/field seismologist",
        "Geoscientist",
        "Glass blower/designer",
        "Government social research officer",
        "Graphic designer",
        "Haematologist",
        "Health and safety adviser",
        "Health and safety inspector",
        "Health physicist",
        "Health promotion specialist",
        "Health service manager",
        "Health visitor",
        "Herbalist",
        "Heritage manager",
        "Herpetologist",
        "Higher education careers adviser",
        "Higher education lecturer",
        "Historic buildings inspector/conservation officer",
        "Holiday representative",
        "Homeopath",
        "Horticultural consultant",
        "Horticultural therapist",
        "Horticulturist, amenity",
        "Horticulturist, commercial",
        "Hospital doctor",
        "Hospital pharmacist",
        "Hotel manager",
        "Housing manager/officer",
        "Human resources officer",
        "Hydrogeologist",
        "Hydrographic surveyor",
        "Hydrologist",
        "Illustrator",
        "Immigration officer",
        "Immunologist",
        "Industrial buyer",
        "Industrial/product designer",
        "Information officer",
        "Information systems manager",
        "Insurance account manager",
        "Insurance broker",
        "Insurance claims handler",
        "Insurance risk surveyor",
        "Insurance underwriter",
        "Intelligence analyst",
        "Interior and spatial designer",
        "International aid/development worker",
        "Interpreter",
        "Investment analyst",
        "Investment banker, corporate",
        "Investment banker, operational",
        "IT consultant",
        "IT sales professional",
        "IT technical support officer",
        "IT trainer",
        "Jewellery designer",
        "Journalist, broadcasting",
        "Journalist, magazine",
        "Journalist, newspaper",
        "Land",
        "Land/geomatics surveyor",
        "Landscape architect",
        "Lawyer",
        "Learning disability nurse",
        "Learning mentor",
        "Lecturer, further education",
        "Lecturer, higher education",
        "Legal executive",
        "Legal secretary",
        "Leisure centre manager",
        "Lexicographer",
        "Librarian, academic",
        "Librarian, public",
        "Licensed conveyancer",
        "Lighting technician, broadcasting/film/video",
        "Lobbyist",
        "Local government officer",
        "Location manager",
        "Logistics and distribution manager",
        "Loss adjuster, chartered",
        "Magazine features editor",
        "Magazine journalist",
        "Maintenance engineer",
        "Make",
        "Management consultant",
        "Manufacturing engineer",
        "Manufacturing systems engineer",
        "Marine scientist",
        "Market researcher",
        "Marketing executive",
        "Materials engineer",
        "Mechanical engineer",
        "Media buyer",
        "Media planner",
        "Medical illustrator",
        "Medical laboratory scientific officer",
        "Medical physicist",
        "Medical sales representative",
        "Medical secretary",
        "Medical technical officer",
        "Mental health nurse",
        "Merchandiser, retail",
        "Merchant navy officer",
        "Metallurgist",
        "Meteorologist",
        "Microbiologist",
        "Midwife",
        "Minerals surveyor",
        "Mining engineer",
        "Mudlogger",
        "Multimedia programmer",
        "Multimedia specialist",
        "Museum education officer",
        "Museum/gallery conservator",
        "Museum/gallery curator",
        "Museum/gallery exhibitions officer",
        "Music therapist",
        "Music tutor",
        "Musician",
        "Nature conservation officer",
        "Naval architect",
        "Network engineer",
        "Neurosurgeon",
        "Newspaper journalist",
        "Nurse, adult",
        "Nurse, children's",
        "Nurse, learning disability",
        "Nurse, mental health",
        "Nutritional therapist",
        "Occupational hygienist",
        "Occupational psychologist",
        "Occupational therapist",
        "Oceanographer",
        "Office manager",
        "Oncologist",
        "Operational investment banker",
        "Operational researcher",
        "Operations geologist",
        "Ophthalmologist",
        "Optician, dispensing",
        "Optometrist",
        "Orthoptist",
        "Osteopath",
        "Outdoor activities/education manager",
        "Paediatric nurse",
        "Paramedic",
        "Passenger transport manager",
        "Patent attorney",
        "Patent examiner",
        "Pathologist",
        "Pension scheme manager",
        "Pensions consultant",
        "Personal assistant",
        "Personnel officer",
        "Petroleum engineer",
        "Pharmacist, community",
        "Pharmacist, hospital",
        "Pharmacologist",
        "Photographer",
        "Physicist, medical",
        "Physiological scientist",
        "Physiotherapist",
        "Phytotherapist",
        "Pilot, airline",
        "Planning and development surveyor",
        "Plant breeder/geneticist",
        "Podiatrist",
        "Police officer",
        "Politician's assistant",
        "Presenter, broadcasting",
        "Press photographer",
        "Press sub",
        "Primary school teacher",
        "Print production planner",
        "Printmaker",
        "Prison officer",
        "Private music teacher",
        "Probation officer",
        "Producer, radio",
        "Producer, television/film/video",
        "Product designer",
        "Product manager",
        "Product/process development scientist",
        "Production assistant, radio",
        "Production assistant, television",
        "Production designer, theatre/television/film",
        "Production engineer",
        "Production manager",
        "Professor Emeritus",
        "Programme researcher, broadcasting/film/video",
        "Programmer, applications",
        "Programmer, multimedia",
        "Programmer, systems",
        "Proofreader",
        "Psychiatric nurse",
        "Psychiatrist",
        "Psychologist, clinical",
        "Psychologist, counselling",
        "Psychologist, educational",
        "Psychologist, forensic",
        "Psychologist, occupational",
        "Psychologist, prison and probation services",
        "Psychologist, sport and exercise",
        "Psychotherapist",
        "Psychotherapist, child",
        "Psychotherapist, dance movement",
        "Public affairs consultant",
        "Public house manager",
        "Public librarian",
        "Public relations account executive",
        "Public relations officer",
        "Publishing copy",
        "Publishing rights manager",
        "Purchasing manager",
        "Quality manager",
        "Quantity surveyor",
        "Quarry manager",
        "Race relations officer",
        "Radiation protection practitioner",
        "Radio broadcast assistant",
        "Radio producer",
        "Radiographer, diagnostic",
        "Radiographer, therapeutic",
        "Ranger/warden",
        "Records manager",
        "Recruitment consultant",
        "Recycling officer",
        "Regulatory affairs officer",
        "Research officer, government",
        "Research officer, political party",
        "Research officer, trade union",
        "Research scientist (life sciences)",
        "Research scientist (maths)",
        "Research scientist (medical)",
        "Research scientist (physical sciences)",
        "Restaurant manager",
        "Restaurant manager, fast food",
        "Retail banker",
        "Retail buyer",
        "Retail manager",
        "Retail merchandiser",
        "Risk analyst",
        "Risk manager",
        "Runner, broadcasting/film/video",
        "Rural practice surveyor",
        "Sales executive",
        "Sales professional, IT",
        "Sales promotion account executive",
        "Science writer",
        "Scientific laboratory technician",
        "Scientist, audiological",
        "Scientist, biomedical",
        "Scientist, clinical (histocompatibility and immunogenetics)",
        "Scientist, forensic",
        "Scientist, marine",
        "Scientist, physiological",
        "Scientist, product/process development",
        "Scientist, research (life sciences)",
        "Scientist, research (maths)",
        "Scientist, research (medical)",
        "Scientist, research (physical sciences)",
        "Scientist, water quality",
        "Secondary school teacher",
        "Secretary/administrator",
        "Secretary, company",
        "Seismic interpreter",
        "Senior tax professional/tax inspector",
        "Set designer",
        "Ship broker",
        "Site engineer",
        "Social research officer, government",
        "Social researcher",
        "Social worker",
        "Software engineer",
        "Soil scientist",
        "Solicitor",
        "Solicitor, Scotland",
        "Sound technician, broadcasting/film/video",
        "Special educational needs teacher",
        "Special effects artist",
        "Speech and language therapist",
        "Sport and exercise psychologist",
        "Sports administrator",
        "Sports coach",
        "Sports development officer",
        "Sports therapist",
        "Stage manager",
        "Statistician",
        "Structural engineer",
        "Sub",
        "Surgeon",
        "Surveyor, building",
        "Surveyor, building control",
        "Surveyor, commercial/residential",
        "Surveyor, hydrographic",
        "Surveyor, insurance",
        "Surveyor, land/geomatics",
        "Surveyor, minerals",
        "Surveyor, mining",
        "Surveyor, planning and development",
        "Surveyor, quantity",
        "Surveyor, rural practice",
        "Systems analyst",
        "Systems developer",
        "Tax adviser",
        "Tax inspector",
        "Teacher, adult education",
        "Teacher, early years/pre",
        "Teacher, English as a foreign language",
        "Teacher, music",
        "Teacher, primary school",
        "Teacher, secondary school",
        "Teacher, special educational needs",
        "Teaching laboratory technician",
        "Technical author",
        "Technical brewer",
        "Technical sales engineer",
        "TEFL teacher",
        "Telecommunications researcher",
        "Television camera operator",
        "Television floor manager",
        "Television production assistant",
        "Television/film/video producer",
        "Textile designer",
        "Theatre director",
        "Theatre manager",
        "Theatre stage manager",
        "Theme park manager",
        "Therapeutic radiographer",
        "Therapist, art",
        "Therapist, drama",
        "Therapist, horticultural",
        "Therapist, music",
        "Therapist, nutritional",
        "Therapist, occupational",
        "Therapist, speech and language",
        "Therapist, sports",
        "Tour manager",
        "Tourism officer",
        "Tourist information centre manager",
        "Town planner",
        "Toxicologist",
        "Trade mark attorney",
        "Trade union research officer",
        "Trading standards officer",
        "Training and development officer",
        "Translator",
        "Transport planner",
        "Travel agency manager",
        "Tree surgeon",
        "Veterinary surgeon",
        "Video editor",
        "Visual merchandiser",
        "Volunteer coordinator",
        "Warden/ranger",
        "Warehouse manager",
        "Waste management officer",
        "Water engineer",
        "Water quality scientist",
        "Web designer",
        "Wellsite geologist",
        "Writer",
        "Youth worker",
    )

    @classmethod
    def job(cls):
        return cls.random_element(cls.jobs)



# coding=utf-8
from __future__ import unicode_literals
from .. import Provider as SsnProvider


class Provider(SsnProvider):
    ssn_formats = ("?#########",)

    @classmethod
    def ssn(cls):
        return cls.bothify(cls.random_element(cls.ssn_formats)).upper()



localized = True

from .. import BaseProvider


class Provider(BaseProvider):
    formats = ['{{first_name}} {{last_name}}', ]

    first_names = ['John', 'Jane']

    last_names = ['Doe', ]

    def name(self):
        """
        :example 'John Doe'
        """
        pattern = self.random_element(self.formats)
        return self.generator.parse(pattern)

    @classmethod
    def first_name(cls):
        return cls.random_element(cls.first_names)

    @classmethod
    def last_name(cls):
        return cls.random_element(cls.last_names)

    def name_male(self):
        if hasattr(self, 'formats_male'):
            formats = self.formats_male
        else:
            formats = self.formats
        pattern = self.random_element(formats)
        return self.generator.parse(pattern)

    def name_female(self):
        if hasattr(self, 'formats_female'):
            formats = self.formats_female
        else:
            formats = self.formats
        pattern = self.random_element(formats)
        return self.generator.parse(pattern)

    @classmethod
    def first_name_male(cls):
        if hasattr(cls, 'first_names_male'):
            return cls.random_element(cls.first_names_male)
        return cls.first_name()

    @classmethod
    def first_name_female(cls):
        if hasattr(cls, 'first_names_female'):
            return cls.random_element(cls.first_names_female)
        return cls.first_name()

    @classmethod
    def last_name_male(cls):
        if hasattr(cls, 'last_names_male'):
            return cls.random_element(cls.last_names_male)
        return cls.last_name()

    @classmethod
    def last_name_female(cls):
        if hasattr(cls, 'last_names_female'):
            return cls.random_element(cls.last_names_female)
        return cls.last_name()

    @classmethod
    def prefix(cls):
        if hasattr(cls, 'prefixes'):
            return cls.random_element(cls.prefixes)
        if hasattr(cls, 'prefixes_male') and hasattr(cls, 'prefixes_female'):
            prefixes = cls.random_element((cls.prefixes_male, cls.prefixes_female))
            return cls.random_element(prefixes)
        return ''

    @classmethod
    def prefix_male(cls):
        if hasattr(cls, 'prefixes_male'):
            return cls.random_element(cls.prefixes_male)
        return cls.prefix()

    @classmethod
    def prefix_female(cls):
        if hasattr(cls, 'prefixes_female'):
            return cls.random_element(cls.prefixes_female)
        return cls.prefix()

    @classmethod
    def suffix(cls):
        if hasattr(cls, 'suffixes'):
            return cls.random_element(cls.suffixes)
        if hasattr(cls, 'suffixes_male') and hasattr(cls, 'suffixes_female'):
            suffixes = cls.random_element((cls.suffixes_male, cls.suffixes_female))
            return cls.random_element(suffixes)
        return ''

    @classmethod
    def suffix_male(cls):
        if hasattr(cls, 'suffixes_male'):
            return cls.random_element(cls.suffixes_male)
        return cls.suffix()

    @classmethod
    def suffix_female(cls):
        if hasattr(cls, 'suffixes_female'):
            return cls.random_element(cls.suffixes_female)
        return cls.suffix()
